@@ -1,5 +1,5 @@
 /*************************************************************************************
- *  Copyright (C) 2007 by Aleix Pol <aleixpol@gmail.com>                             *
+ *  Copyright (C) 2007 by Aleix Pol <aleixpol@kde.org>                               *
  *                                                                                   *
  *  This program is free software; you can redistribute it and/or                    *
  *  modify it under the terms of the GNU General Public License                      *
@@ -25,15 +25,19 @@
 #include "analitzaexport.h"
 #include "object.h"
 
+class QDomElement;
+
+namespace Analitza
+{
+class Ci;
 class Container;
 class Cn;
-class QDomElement;
 
 /**
  *	This class represents an expression.
  *	Expression let to convert it to string, MathML and make some little queries to it, without calculating anything.
  *
- *	@author Aleix Pol <aleixpol@gmail.com>
+ *	@author Aleix Pol <aleixpol@kde.org>  
  */
 
 class ANALITZA_EXPORT Expression
@@ -62,7 +66,7 @@ class ANALITZA_EXPORT Expression
 		 *	@param exp expression to be assigned
 		 *	@param mathml format of the expression
 		 */
-		Expression(const QString& exp, bool mathml=false);
+		explicit Expression(const QString& exp, bool mathml=false);
 		
 		/** Destructor */
 		~Expression();
@@ -97,21 +101,31 @@ class ANALITZA_EXPORT Expression
 		 */
 		Expression operator=(const Expression& e);
 		
-		/**
-		 *	Returns the uplimit field tree.
-		 */
-		Expression uplimit() const;
-		
-		/**
-		 *	Returns the downlimit field tree.
-		 */
-		Expression downlimit() const;
-		
 		/**
 		 *	Returns whether it is a lambda-expression.
 		 */
 		bool isLambda() const;
 		
+		/**
+		 *	Returns the expression of the lambda body (without resolving the dependencies)
+		 */
+		Expression lambdaBody() const Q_REQUIRED_RESULT;
+		
+		/**
+		 *	Returns whether it is a vector expression.
+		 */
+		bool isVector() const;
+		
+		/**
+		 *	Returns whether it is a vector expression.
+		 */
+		bool isList() const;
+		
+		/**
+		 *	Returns the element at @p position in a vector
+		 */
+		Expression elementAt(int position) const;
+		
 		/**
 		 *	Returns the tree associated to this object.
 		 */
@@ -154,10 +168,20 @@ class ANALITZA_EXPORT Expression
 		QStringList bvarList() const;
 		
 		/** @returns Value representation of the expression. */
-		Cn value() const;
+		Cn toReal() const;
 		
 		/** @returns true if the expression is a value, false otherwise. */
-		bool isValue() const;
+		bool isReal() const;
+		
+		/** @returns a list of the parameters in case this expression represents
+			a lambda construction. */
+		QList<Ci*> parameters() const;
+		
+		/** In case it was a vector or list, it returns a list of each expression on the vector. */
+		QList<Expression> toExpressionList() const;
+		
+		/** renames the @p depth -th variable into @p newName */
+		void renameArgument(int depth, const QString& newName);
 		
 		/**
 		 *	Converts a @p tag to an object type.
@@ -165,15 +189,22 @@ class ANALITZA_EXPORT Expression
 		static enum Object::ObjectType whatType(const QString& tag);
 		
 		/**
-		 *	Returns whether @p s is MathML or not. Very simple.
+		 *	@returns whether @p s is MathML or not. Very simple.
 		 */
 		static bool isMathML(const QString& s) { return !s.isEmpty() && s[0]=='<'; }
 		
-	private:
-		Object* branch(const QDomElement& elem);
+		static void computeDepth(Object* o);
 		
+		/**
+		 * @returns an expression containing a list of every expression passed on @p exps on the form:
+		 *    list { exps[0], exps[1], ... }
+		 */
+		static Expression constructList(const QList<Expression> & exps);
+	private:
 		class ExpressionPrivate;
 		QSharedDataPointer<ExpressionPrivate> d;
 };
 
+}
+
 #endif
