@@ -17,15 +17,18 @@
  *************************************************************************************/
 
 #include "analitzatest.h"
-#include "analitza.h"
+#include "analyzer.h"
 #include <qtest_kde.h>
 #include <cmath>
 
+#include "apply.h"
 #include "container.h"
 #include "variables.h"
 #include "vector.h"
 #include "value.h"
 #include <variable.h>
+#include <analitzautils.h>
+//#include <operations.h>
 
 using namespace std;
 using Analitza::Cn;
@@ -47,7 +50,7 @@ AnalitzaTest::~AnalitzaTest()
 
 void AnalitzaTest::initTestCase()
 {
-	a=new Analitza::Analitza;
+	a=new Analitza::Analyzer;
 }
 
 void AnalitzaTest::cleanupTestCase()
@@ -61,6 +64,10 @@ void AnalitzaTest::testTrivialCalculate_data()
 	QTest::addColumn<double>("result");
 
 	QTest::newRow("a value") << "2" << 2.;
+	QTest::newRow("val.e0") << "12.0e-02" << 12e-2;
+	QTest::newRow("vale") << "12e-2" << 12e-2;
+	QTest::newRow("val") << "12e2" << 12e2;
+	
 	QTest::newRow("simple addition") << "2+2" << 4.;
 	QTest::newRow("simple power") << "2**99" << pow(2., 99.);
 	QTest::newRow("simple multiplication") << "3*3" << 9.;
@@ -78,11 +85,15 @@ void AnalitzaTest::testTrivialCalculate_data()
 	QTest::newRow("boolean and") << "and(1,0)" << 0.;
 	QTest::newRow("boolean or") << "or(0,1)" << 1.;
 	QTest::newRow("boolean not") << "not(0)" << 1.;
-	QTest::newRow("lambda") << "(x->x+2)(2)" << 4.;
+	QTest::newRow("lambda")  << "(x->x+2)(2)" << 4.;
+	QTest::newRow("lambda2") << "(x->3*x^2)(1)" << 3.;
+	QTest::newRow("lambda3") << "(x->x*sum(t:t=0..3))(2)" << 12.;
 	
 	//comprehension
 	QTest::newRow("sum.2bvars") << "sum(x*y : (x, y)=1..3)" << 36.;
 	QTest::newRow("sum.list") << "sum(x : x@list{1,5,44})" << 50.;
+	
+	QTest::newRow("sum.sum") << "sum(sum(x : x=0..i) : i=0..10)" << 220.;
 }
 
 void AnalitzaTest::testTrivialCalculate()
@@ -93,10 +104,13 @@ void AnalitzaTest::testTrivialCalculate()
 	QCOMPARE(e.isCorrect(), true);
 	
 	a->setExpression(e);
+	
+	if(!a->isCorrect()) qDebug() << "error: " << a->errors();
 	QVERIFY(a->isCorrect());
 	QCOMPARE(a->evaluate().toReal().value(), result);
 	QVERIFY(a->isCorrect());
 	Expression ee=a->calculate();
+	if(!a->isCorrect()) qDebug() << "error: " << a->errors();
 	QVERIFY(a->isCorrect());
 	QCOMPARE(ee.toReal().value(), result);
 	QVERIFY(a->isCorrect());
@@ -120,7 +134,7 @@ void AnalitzaTest::testTrivialEvaluate_data()
 	QTest::newRow("minus3.2") << "minus(x,x,x,x,x,x)" << "-4*x";
 	QTest::newRow("addition") << "x+x" << "2*x";
 	QTest::newRow("simple polynomial") << "x+x+x**2+x**2" << "2*x+2*x^2";
-	QTest::newRow("simplification of unary minus in times") << "x*(-x)" << "-(x^2)";
+	QTest::newRow("simplification of unary minus in times") << "x*(-x)" << "-x^2";
 	QTest::newRow("strange") << "0*x-1*1" << "-1";
 	QTest::newRow("strange2") << "x-x" << "0";
 	QTest::newRow("old leak") << "x^1" << "x";
@@ -138,7 +152,7 @@ void AnalitzaTest::testTrivialEvaluate_data()
 	
 	QTest::newRow("sum") << "sum(n : n=1..99)" << "4950";
 	QTest::newRow("sum times") << "x*sum(n : n=0..99)" << "4950*x";
-	QTest::newRow("unrelated sum") << "sum(x : n=0..99)" << "99*x";
+	QTest::newRow("unrelated sum") << "sum(x : n=0..99)" << "100*x";
 	
 	QTest::newRow("product") << "product(n : n=1..5)" << "120";
 	QTest::newRow("factorial") << "factorial(5)" << "120";
@@ -168,7 +182,7 @@ void AnalitzaTest::testTrivialEvaluate_data()
 	QTest::newRow("lists2") << "union(list{w}, x, list{y}, list{z})" << "union(list { w }, x, list { y, z })";
 	
 	QTest::newRow("sum.2bvars") << "sum(x*w : (x, y)=1..3)" << "18*w";
-// 	QTest::newRow("sum.list") << "sum(x+y : x@list{x,y,z})" << "x+4*y+z";
+	QTest::newRow("sum.list") << "sum(x+y : x@list{x,y,z})" << "x+4*y+z";
 }
 
 void AnalitzaTest::testTrivialEvaluate()
@@ -176,9 +190,15 @@ void AnalitzaTest::testTrivialEvaluate()
 	QFETCH(QString, expression);
 	QFETCH(QString, result);
 	
-	a->setExpression(Expression(expression, false));
+	Expression e(expression, false);
+	a->setExpression(e);
 	if(!a->isCorrect())
 		qDebug() << "errors:" << a->errors();
+	
+	qDeleteAll(*a->variables());
+	a->variables()->clear();
+	a->variables()->initializeConstants();
+	
 	QVERIFY(a->isCorrect());
 	QCOMPARE(a->evaluate().toString(), result);
 }
@@ -188,6 +208,7 @@ void AnalitzaTest::testDerivativeSimple_data()
 	QTest::addColumn<QString>("expression");
 	QTest::addColumn<QString>("result");
 	
+	QTest::newRow("dumb") << "x" << "1";
 	QTest::newRow("simple polynomial") << "x^3+1" << "3*x^2";
 	QTest::newRow("power and sinus") << "x^2+sin(x)" << "2*x+cos(x)";
 	QTest::newRow("power") << "x^2" << "2*x";
@@ -201,6 +222,7 @@ void AnalitzaTest::testDerivativeSimple_data()
 	QTest::newRow("lambda") << "x->3" << "0";
 	QTest::newRow("timesminus") << "1-x*sin(x)" << "-sin(x)-x*cos(x)";
 	QTest::newRow("timesminus2") << "cos(x)-x*sin(x)" << "-2*sin(x)-x*cos(x)";
+	QTest::newRow("log") << "log(x)" << "1/(2.30258509299*x)";
 }
 
 void AnalitzaTest::testDerivativeSimple()
@@ -208,32 +230,41 @@ void AnalitzaTest::testDerivativeSimple()
 	QFETCH(QString, expression);
 	QFETCH(QString, result);
 	
+	qDeleteAll(*a->variables());
+	a->variables()->clear();
+	a->variables()->initializeConstants();
+	
 	Expression e(expression, false);
 	a->setExpression(e);
 	QVERIFY(a->isCorrect());
-	a->setExpression(a->derivative());
+	a->setExpression(a->derivative("x"));
 	a->simplify();
 	Expression deriv=a->expression();
-	QCOMPARE(deriv.toString(), result);
+	QCOMPARE(deriv.toString(), "x->"+result);
+	if(!a->isCorrect()) qDebug() << "errors: " << a->errors();
 	QVERIFY(a->isCorrect());
 	
 	double val=1.;
-	QList<QPair<QString, double> > vars;
-	vars.append(QPair<QString, double>("x", val));
+	QVector<Object*> vars;
+	vars.append(new Cn(val));
 	
-	a->setExpression(e);
+	a->setExpression(Expression("x->"+expression, false));
 	double valCalc=a->derivative(vars);
+	qDeleteAll(vars);
+	
 	if(a->isCorrect()) {
 		Expression ee(QString("(x->%1)(%2)").arg(result).arg(val));
 		a->setExpression(ee);
-		Cn valExp(a->calculate().toReal());
+		QVERIFY(a->isCorrect());
 		
-		QCOMPARE(QString::number(valCalc), QString::number(valExp.value()));
+		Expression r=a->calculate();
+		
+		if(a->isCorrect())
+			QCOMPARE(QString::number(valCalc), QString::number(r.toReal().value()));
 	}
 	a->setExpression(Expression("diff("+expression+":x)", false));
 	a->simplify();
 	QVERIFY(a->isCorrect());
-	a->variables()->destroy("x");
 	deriv=a->evaluate();
 	
 	QCOMPARE(deriv.toString(), "x->"+result);
@@ -256,28 +287,23 @@ void AnalitzaTest::testCorrection_data()
 	script << "f(1)";
 	QTest::newRow("simple func") << script << "3";
 	
-	script.clear();
-	script << "t:=(c, c1, c2, t1, t2)->(t2-t1)/(c2-c1)*(c-c1)+t1";
-	script << "t(1,2,3,4,5)";
-	QTest::newRow("long func") << script << "3";
+// 	script.clear();
+// 	script << "t:=(c, c1, c2, t1, t2)->(t2-t1)/(c2-c1)*(c-c1)+t1";
+// 	script << "t(1,2,3,4,5)";
+// 	QTest::newRow("long func") << script << "3";
 	
 	script.clear();
-	script << "fact:=n->piecewise { eq(n,1)?1, ? n*fact(n-1) }";
+	script << "fact:=n->piecewise { n=1?1, ? n*fact(n-1) }";
 	script << "fact(5)";
 	QTest::newRow("piecewise factorial") << script << "120";
 	
 	script.clear();
-	script << "fib:=n->piecewise { eq(n,0)?0, eq(n,1)?1, ?fib(n-1)+fib(n-2) }";
+	script << "fib:=n->piecewise { n=0?0, n=1?1, ?fib(n-1)+fib(n-2) }";
 	script << "fib(6)";
 	QTest::newRow("piecewise fibonacci") << script << "8";
 	
 	script.clear();
-	script << "func:=n->n+1";
-	script << "func(5)";
-	QTest::newRow("simple function") << script << "6";
-	
-	script.clear();
-	script << "n:=9";
+	script << "n:=vector{1}";
 	script << "func:=n->n+1";
 	script << "func(5)";
 	QTest::newRow("simple function, shadowed parameter") << script << "6";
@@ -294,6 +320,7 @@ void AnalitzaTest::testCorrection_data()
 	
 	script.clear();
 	script << "fv:=vector{x->x, x->x+2}";
+	script << "(selector(1, fv))(1)";
 	script << "(selector(1, fv))(1)+(selector(2, fv))(2)";
 	QTest::newRow("selector+lambda") << script << "5";
 	
@@ -307,6 +334,12 @@ void AnalitzaTest::testCorrection_data()
 			<< "valueTableRec(x->x**2, list{1,2,3}, 3)";
 	QTest::newRow("yay") << script << "list { 9, 4, 1 }";
 	
+	script.clear();
+	script << "f:=ff->(y->ff(y))";
+// 	script << "f(x->x**2)";
+	script << "(f(x->x**2))(2)";
+	QTest::newRow("yay2") << script << "4";
+	
 	script.clear();
 	script <<	"findroot:=(der, dee)->piecewise { dee>1 ?"
 				"piecewise { rem(der, dee)=0 ? true, ? findroot(der, dee-1)  }, ? false }";
@@ -315,6 +348,34 @@ void AnalitzaTest::testCorrection_data()
 				" isprime(from)? union(list{from}, primes(from+1, to)), ? primes(from+1, to)}";
 	script << "primes(1, 25)";
 	QTest::newRow("primes") << script << "list { 1, 2, 3, 5, 7, 11, 13, 17, 19, 23 }";
+	
+	script.clear();
+	script << "f:=v->sum(i**2 : i@v)";
+	script << "f(list{1,2,3})";
+	script << "f(vector{1,2,3})";
+	QTest::newRow("sum.list") << script << "14";
+	
+	script.clear();
+	script << "f:=o->vector { x->x+o, x->x*o }";
+	script << "vector { selector(1, f(3)), selector(1, f(4)) }";
+	QTest::newRow("lambda") << script << "vector { x->x+3, x->x+4 }";
+	
+	script.clear();
+	script << "comb:=(n, i)->factorial(n)/(factorial(i)*factorial(n-i))"
+		   << "p:=10^-2"
+		   << "pu:=n->sum(  comb(n,i)*p^(n-i)*(1-p)*sum(x:x=0..i)  :i=0..(floor((n-1)/2)))"
+		   << "pu(5)";
+	
+	QTest::newRow("bug241047") << script << "2.97495e-05";
+	
+	script.clear();
+	script << "comb:=(n, i)->factorial(n)/(factorial(i)*factorial(n-i))"
+		   << "probability:=(place, case, totalprobability,"
+					"positive, negative)->(comb(place,"
+					"case)*(positive/totalprobability)^case)*(negative/totalprobability)^(place-case)"
+		   << "sum(probability(5, t, 6, 1, 5):t=0..5)";
+	
+	QTest::newRow("probabilities") << script << "1";
 }
 
 //testCalculate
@@ -323,55 +384,66 @@ void AnalitzaTest::testCorrection()
 	QFETCH(QStringList, expression);
 	QFETCH(QString, result);
 	
-	Analitza::Analitza b;
-	Expression res;
+	Expression last;
+	Analitza::Analyzer b1;
 	foreach(const QString &exp, expression) {
 		Expression e(exp, false);
-		if(!e.isCorrect()) qDebug() << "error" << e.error();
+		if(!e.isCorrect()) qDebug() << "error:" << e.error();
 		QVERIFY(e.isCorrect());
 		
-		b.setExpression(e);
-		QVERIFY(b.isCorrect());
-		b.calculate();
-		if(!b.isCorrect()) qDebug() << "errors:" << b.errors();
-		QVERIFY(b.isCorrect());
+		b1.setExpression(e);
+		
+		if(!b1.isCorrect()) qDebug() << "errors: " << b1.errors();
+		QVERIFY(b1.isCorrect());
+		last = b1.calculate();
+		if(!b1.isCorrect()) qDebug() << "errors:" << e.toString() << b1.errors();
+		QVERIFY(b1.isCorrect());
 	}
-	QCOMPARE(b.calculate().toString(), result);
+	QCOMPARE(last.toString(), result);
 	
+	Analitza::Analyzer b;
+	Expression evalResult;
 	foreach(const QString &exp, expression) {
 		Expression e(exp, false);
-// 		qDebug() << e.error();
 		QVERIFY(e.isCorrect());
 		
 		b.setExpression(e);
 		QVERIFY(b.isCorrect());
-		res=b.evaluate();
+		evalResult=b.evaluate();
 		QVERIFY(b.isCorrect());
 	}
-	QCOMPARE(res.toString(), result);
+	QCOMPARE(evalResult.toString(), result);
 }
 
-void AnalitzaTest::testUncorrection_data()
+void AnalitzaTest::testTypeUncorrection()
+{
+	QFETCH(QStringList, expression);
+	
+	bool correct=false;
+	Analitza::Analyzer b;
+	
+	foreach(const QString &exp, expression) {
+		Expression e(exp, false);
+		b.setExpression(e);
+		correct=b.isCorrect();
+		
+		if(correct)
+			b.calculate().toReal().value();
+		
+		if(!correct || !b.isCorrect())
+			break;
+	}
+	QVERIFY(!correct);
+}
+
+void AnalitzaTest::testTypeUncorrection_data()
 {
 	QTest::addColumn<QStringList>("expression");
-	QTest::newRow("wrong count") << QStringList("plus(1)");
-	QTest::newRow("summatory with unknown uplimit") << QStringList("sum(x : x=1..)");
-	QTest::newRow("summatory with unknown downlimit") << QStringList("sum(x : x=..3)");
-	QTest::newRow("summatory with uncorrect downlimit") << QStringList("sum(x : x=x..3)");
 	QTest::newRow("vect+sin") << QStringList("3+sin(vector{3,4,2})");
 	QTest::newRow("scalar+card") << QStringList("card(3)");
-	QTest::newRow("wrong parameters") << QStringList("selector(vector{1,1/3})");
 	QTest::newRow("wrong operation") << QStringList("lcm(vector{0}, vector{0})");
-	QTest::newRow("wrong sum") << QStringList("sum(x : x=10..0)");
-	QTest::newRow("recursive var") << QStringList("ww:=ww+1");
-	QTest::newRow("nopiece") << QStringList("fib:=n->piecewise { eq(n,0)?0, eq(n,1)?1, fib(n-1)+fib(n-2) }");
 	
 	QStringList script;
-	script << "a:=b";
-	script << "b:=a";
-	QTest::newRow("var dependency cycle") << script;
-	
-	script.clear();
 	script << "x:=3";
 	script << "x(3)";
 	QTest::newRow("value call") << script;
@@ -382,12 +454,25 @@ void AnalitzaTest::testUncorrection_data()
 	QTest::newRow("call missing parameter") << script;
 }
 
+void AnalitzaTest::testUncorrection_data()
+{
+	QTest::addColumn<QStringList>("expression");
+	QTest::newRow("summatory with uncorrect downlimit1") << QStringList("sum(x : x=y..3)");
+	QTest::newRow("summatory with uncorrect downlimit2") << QStringList("sum(x : x=x..3)");
+	QTest::newRow("wrong sum") << QStringList("sum(x : x=10..0)");
+	
+	QStringList script;
+	script << "a:=b";
+	script << "b:=a";
+	QTest::newRow("var dependency cycle") << script;
+}
+
 void AnalitzaTest::testUncorrection()
 {
 	QFETCH(QStringList, expression);
 	
 	bool correct=false;
-	Analitza::Analitza b;
+	Analitza::Analyzer b;
 	foreach(const QString &exp, expression) {
 		Expression e(exp, false);
 		correct=e.isCorrect();
@@ -422,14 +507,29 @@ void AnalitzaTest::testSimplify_data()
 	QTest::addColumn<QString>("expression");
 	QTest::addColumn<QString>("result");
 	
+	QTest::newRow("identity") << "1*x" << "x";
 	QTest::newRow("minus") << "x-x-x" << "-x";
+	QTest::newRow("compensation") << "-(4*x)+3*x" << "-x";
+	QTest::newRow("compensation*") << "-(x^4)*x^3" << "-x^7";
+	QTest::newRow("powers") << "3**x*5**x" << "3^x*5^x";
+// 	QTest::newRow("powerscomb") << "3**x*3**x" << "9^x";
 	QTest::newRow("no var") << "2+2" << "4";
 	QTest::newRow("simple") << "x+x" << "2*x";
 	QTest::newRow("lambda") << "(x->x+1)(2)" << "3";
-// 	QTest::newRow("lambda2") << "(x->x+x)(x)" << "x->2*x";
+// 	QTest::newRow("lambda2")<< "(x->x+x)(x)" << "2*x";
 	QTest::newRow("diff") << "diff(x^2:x)" << "x->2*x";
 	QTest::newRow("sum times") << "sum(n*x : n=0..99)" << "4950*x";
 	QTest::newRow("levelout") << "-y-(x+y)" << "-2*y-x";
+	QTest::newRow("sum") << "n->sum((i+n) * i : i=0..9)" << "n->sum((i+n)*i:i=0..9)";
+	QTest::newRow("sum.sum") << "k->sum(sum(x:x=0..i):i=0..k)" << "k->sum(sum(x:x=0..i):i=0..k)";
+	QTest::newRow("unrelated sum") << "sum(x : n=0..99)" << "100*x";
+	
+	QTest::newRow("piecewise1") << "piecewise { 1=2 ? 4, ? 3}" << "3";
+	QTest::newRow("piecewise2") << "piecewise { x=2 ? 4, ? 3}" << "piecewise { x=2 ? 4, ? 3 }";
+	QTest::newRow("piecewise3") << "piecewise { 2=2 ? 4, ? 3}" << "4";
+	
+	QTest::newRow("sum.dlul") << "w->sum(x : x=(floor(2.5)+w)..(ceiling(2.5)))" << "w->sum(x:x=w+2..3)";
+	QTest::newRow("trig") << "sin(x)/cos(x)" << "sin(x)/cos(x)";
 }
 
 void AnalitzaTest::testSimplify()
@@ -438,6 +538,7 @@ void AnalitzaTest::testSimplify()
 	QFETCH(QString, result);
 	
 	a->setExpression(Expression(expression, false));
+	if(!a->isCorrect()) qDebug() << "error:" << a->errors();
 	QVERIFY(a->isCorrect());
 	a->simplify();
 	QCOMPARE(a->expression().toString(), result);
@@ -452,6 +553,11 @@ void AnalitzaTest::testEvaluate_data()
 	script << "f:=x->x";
 	script << "f(x)";
 	QTest::newRow("function parameter") << script << "x";
+	
+	script.clear();
+	script << "pu:=n->sum(p**i:i=0..(floor(n)))";
+	script << "pu(3)";
+	QTest::newRow("calls") << script << "sum(p^i:i=0..3)";
 }
 
 void AnalitzaTest::testEvaluate()
@@ -459,7 +565,7 @@ void AnalitzaTest::testEvaluate()
 	QFETCH(QStringList, expression);
 	QFETCH(QString, result);
 	
-	Analitza::Analitza b;
+	Analitza::Analyzer b;
 	Expression res;
 	foreach(const QString &exp, expression) {
 		Expression e(exp, false);
@@ -470,7 +576,7 @@ void AnalitzaTest::testEvaluate()
 		QVERIFY(b.isCorrect());
 		res=b.evaluate();
 		QVERIFY(b.isCorrect());
-		b.calculate();
+// 		b.calculate(); //we can do that just if we know that all variables doesn't have dependencies
 	}
 	QCOMPARE(res.toString(), result);
 }
@@ -483,7 +589,8 @@ void AnalitzaTest::testVector()
 	QCOMPARE(e.isCorrect(), true);
 	
 	a->setExpression(e);
-	QCOMPARE(a->isCorrect(), true);
+	if(!a->isCorrect()) qDebug() << "error:" << a->errors();
+	QVERIFY(a->isCorrect());
 	QCOMPARE(a->calculate().toString(), result);
 	QCOMPARE(a->evaluate().toString(), result);
 }
@@ -511,7 +618,8 @@ void AnalitzaTest::testVector_data()
 	
 	QTest::newRow("selector1+list") << "selector(1, list{1,2,3})" << "1";
 	QTest::newRow("selector2+list") << "selector(2, list{1,2,3})" << "2";
-	QTest::newRow("selector3+list") << "selector(3, list{1,2}+list{3})" << "3";
+	QTest::newRow("selector3+list") << "selector(3, union(list{1,2}, list{3}))" << "3";
+	QTest::newRow("union") << "union(list{1,2}, list{3})" << "list { 1, 2, 3 }";
 }
 
 void AnalitzaTest::testCrash_data()
@@ -662,6 +770,8 @@ void AnalitzaTest::testOperators()
 	if(o.operatorType()==Operator::function)
 		return;
 	
+// 	QVERIFY(!Analitza::Operations::infer(o.operatorType()).isEmpty() || !Analitza::Operations::inferUnary(o.operatorType()).isEmpty());
+	
 	Vector* v=new Vector(3);
 	v->appendBranch(new Cn(0.));
 	v->appendBranch(new Cn(1.));
@@ -688,7 +798,7 @@ void AnalitzaTest::testOperators()
 	
 	foreach(Object* obj, values) {
 		foreach(int paramCnt, params) {
-			Container* apply=new Container(Container::apply);
+			Analitza::Apply* apply=new Analitza::Apply;
 			apply->appendBranch(new Operator(o));
 			for(; paramCnt>0; paramCnt--)  {
 				apply->appendBranch(obj->copy());
@@ -696,12 +806,12 @@ void AnalitzaTest::testOperators()
 			
 			if(o.isBounded()) {
 				Container *bvar=new Container(Container::bvar);
-				apply->m_params.prepend(bvar);
+				apply->appendBranch(bvar);
 				
 				QList<Object*> bvarValues=QList<Object*>() << new Ci("x");
 				foreach(Object* obvar, bvarValues) {
-					Container* cc=(Container*) apply->copy();
-					Container* bvar=(Container*) cc->m_params[0];
+					Analitza::Apply* cc=(Analitza::Apply*) apply->copy();
+					Container* bvar=(Container*) cc->bvarCi().first();
 					bvar->appendBranch(obvar->copy());
 					
 					Expression e1(cc);
@@ -709,7 +819,7 @@ void AnalitzaTest::testOperators()
 					
 					a->calculate();
 					a->evaluate();
-					a->derivative();
+					a->derivative("x");
 				}
 				qDeleteAll(bvarValues);
 			} else {
@@ -717,7 +827,7 @@ void AnalitzaTest::testOperators()
 				a->setExpression(e);
 				a->calculate();
 				a->evaluate();
-				a->derivative();
+				a->derivative("x");
 			}
 		}
 	}
@@ -727,13 +837,13 @@ void AnalitzaTest::testOperators()
 	QString bvar="x";
 	foreach(double v, diffValues) {
 		foreach(int paramCnt, params) {
-			Container *diffApply=new Container(Container::apply);
+			Analitza::Apply *diffApply=new Analitza::Apply;
 			diffApply->appendBranch(new Operator(Operator::diff));
 			Container* diffBVar=new Container(Container::bvar);
 			diffBVar->appendBranch(new Ci(bvar));
 			diffApply->appendBranch(diffBVar);
 			
-			Container* apply=new Container(Container::apply);
+			Analitza::Apply* apply=new Analitza::Apply;
 			apply->appendBranch(new Operator(o));
 			diffApply->appendBranch(apply);
 			
@@ -745,8 +855,13 @@ void AnalitzaTest::testOperators()
 			a->calculate();
 			a->evaluate();
 			a->simplify();
-			a->derivative();
-			a->derivative(QList< QPair<QString, double> >() << qMakePair(bvar, v));
+			a->derivative("x");
+			
+			Cn* vv = new Cn(v);
+			QVector<Object*> stack;
+			stack += vv;
+			a->derivative(stack);
+			delete vv;
 		}
 	}
 }
