@@ -115,7 +115,9 @@ QString OperatorsModel::sample(Operator oper)
 	QString funcname=oper.toString();
 	QString bounds;
 	if(oper.isBounded()) {
-		bounds=" : var=from..to";
+		bounds=i18nc("Syntax for function bounding", " : var");
+		if(oper.operatorType()==Operator::sum || oper.operatorType()==Operator::product)
+			bounds += i18nc("Syntax for function bounding values", "=from..to");
 	}
 	
 	QString sample = i18n("%1(", funcname);
@@ -146,7 +148,7 @@ QString OperatorsModel::description(Operator o)
 			s = i18n("Division");
 			break;
 		case Operator::minus:
-			s = i18n("Subtraction");
+			s = i18n("Subtraction. Will remove all values from the first one.");
 			break;
 		case Operator::power:
 			s = i18n("Power");
@@ -332,7 +334,7 @@ QString OperatorsModel::description(Operator o)
 			s = i18n("Scalar product");
 			break;
 		case Operator::selector:
-			s = i18n("Select an element from a container");
+			s = i18n("Select the par1-th element of par2 list or vector");
 			break;
 		case Operator::_union:
 			s = i18n("Joins several items of the same type");
@@ -423,13 +425,13 @@ QString OperatorsModel::example(Operator o)
 			s="root(x, 2)";
 			break;
 		case Operator::selector:
-			s="piecewise { x>0 ? selector(1, vector { x, 1/x }), ? selector(2, vector { x, 1/x }) }";
+			s="selector(piecewise { x>0 ? 1, ? 2 }, vector { x, 1/x })";
 			break;
 		case Operator::sum:
-			s="x*sum(t:t=0..3)";
+			s="x*sum(t*t:t=0..3)";
 			break;
 		case Operator::product:
-			s="product(t:t=1..3)";
+			s="product(t+t:t=1..3)";
 			break;
 		case Operator::card:
 			s="card(vector { x, 1, 2 })";
