@@ -22,57 +22,52 @@
 
 #include <kdialog.h>
 
-#include "kalziumpainter.h"
-#include "kalziumschemetype.h"
+#include "kalziumelementproperty.h"
 
 class LegendItem;
-class KalziumGradientType;
 
 /**
  * @author Carsten Niehaus
  *
- * The LegendWidget displays the explanations of what the user is currently 
+ * The LegendWidget displays the explanations of what the user is currently
  * seeing in the table
  */
 class LegendWidget : public QWidget
 {
     Q_OBJECT
 
-    public:
-        LegendWidget( QWidget *parent );
+public:
+    LegendWidget( QWidget *parent );
 
-        ~LegendWidget(){}
+    ~LegendWidget() {}
 
-    private:
-        QPixmap m_pixmap;
+    void LockWidget();
+    void UnLockWidget();
 
-        KalziumSchemeType * m_scheme;
+private:
+    bool m_update;
 
-        KalziumPainter::MODE m_mode;
+    QPixmap m_pixmap;
 
-        KalziumTableType * m_tableType;
+    KalziumElementProperty *m_elementProerty;
 
-        KalziumGradientType * m_gradientType;
+    QList<LegendItem*> m_legendItemList;
 
-        QList<LegendItem*> m_legendItemList;
+    Qt::DockWidgetArea m_dockArea;
 
-        void updateLegendItemLayout( const QList<legendPair>& list );
+    void updateLegendItemLayout( const QList<legendPair>& list );
 
-    public slots:
-        void updateContent();
+public slots:
+    void updateContent();
 
-        void setMode( KalziumPainter::MODE m );
+    void setElementProperty( KalziumElementProperty *propety);
 
-        void setScheme( KalziumSchemeType * type );
-
-        void setTableType( KalziumTableType * type );
-        
-        void setGradientType( KalziumGradientType * type );
+    void setDockArea(Qt::DockWidgetArea newDockArea);
 };
 
 /**
  * A LegendItem is displayed as one small rectangle which represents the
- * color or QBrush in the table with a short explanation for it.
+ * color in the table with a short explanation for it.
  *
  * @author Carsten Niehaus
  */
@@ -80,15 +75,10 @@ class LegendItem : public QWidget
 {
     Q_OBJECT
 
-    public:
-        LegendItem( const QPair<QString, QBrush>& pair, QWidget * parent = 0 );
-        ~LegendItem(){}
+public:
+    LegendItem( const QPair<QString, QColor>& pair, QWidget * parent = 0 );
+    ~LegendItem() {}
 
-    private:
-        QPair<QString, QBrush> m_pair;
-
-    protected:
-        virtual void paintEvent( QPaintEvent * e );
 };
 
 #endif // LEGENDWIDGET_H
