@@ -1,5 +1,5 @@
 /*
- * Copyright 2001-2009 Anne-Marie Mahfouf <annma@kde.org>
+ * Copyright 2001-2010 Anne-Marie Mahfouf <annma@kde.org>
 
      This program is free software; you can redistribute it and/or modify  
      it under the terms of the GNU General Public License as published by  
@@ -87,7 +87,7 @@ KHangManView::KHangManView(KHangMan*parent)
     m_renderer = new QSvgRenderer();
 
     // not the best thing to do, but at least avoid no theme set
-    setTheme(KHMThemeFactory::instance()->buildTheme(0));
+    //setTheme(KHMThemeFactory::instance()->buildTheme(0));
 }
 
 
@@ -211,7 +211,9 @@ void KHangManView::setTheme(KHMTheme *theme)
 
     QString svgpath = KStandardDirs::locate("data", QString("khangman/pics/%1/%2").arg(theme->name(), theme->svgFileName()));
     // we don't allow themes with no svg installed
-    if (!QFile::exists(svgpath)) {
+
+    if (!QFile::exists(svgpath) || theme->svgFileName().isEmpty()) {
+        kDebug() << "SVG file doesn't exists";
         return;
     }
 
@@ -251,7 +253,7 @@ void KHangManView::paintEvent( QPaintEvent * e )
     paintWord(p, e->rect());
     paintMisses(p, e->rect());
     paintHint(p, e->rect());
-    if (m_loser || m_winner) {
+    if(m_loser || m_winner) {
         paintGameOver(p, e->rect());
     }
 }
@@ -333,14 +335,15 @@ void KHangManView::paintMisses(QPainter &p, const QRect& )
 
 void KHangManView::paintHint(QPainter &p, const QRect &rect)
 {
-    if (!Prefs::hint()) {
+    if(!Prefs::hint()) {
         return;
     }
     
     QRect myRect = m_theme->hintRect(size());
-    if (!myRect.intersects(rect)) {
+    if(!myRect.intersects(rect)) {
         return;
     }
+
 /* Debug */  //p.fillRect(myRect, QBrush(Qt::cyan) );
 
     QColor letterColor = m_theme->letterColor();
@@ -371,11 +374,11 @@ void KHangManView::paintHint(QPainter &p, const QRect &rect)
 
 void KHangManView::paintGameOver(QPainter &p, const QRect &rect)
 {
-    if(!Prefs::enableAnimations()) {
+    if (!Prefs::enableAnimations()) {
         m_bgfill=100;
     }
+    
     QString title=m_loser?i18n("You lost. The word was \"%1\".", m_word):i18n("Congratulations! You won!");
-
     p.fillRect(QRect(rect.x(), rect.y(), rect.width(), (int)(rect.height()/100.0*m_bgfill)), QBrush(QColor(0,0,0,70)));
     p.setRenderHint(QPainter::Antialiasing, true);
     QPen pen(Qt::black, 2);
@@ -390,10 +393,10 @@ void KHangManView::paintGameOver(QPainter &p, const QRect &rect)
     p.setFont(tFont);
     p.drawText(rectangle, Qt::AlignCenter, title);
 
-    if(m_bgfill<100) {
+    if (m_bgfill<100) {
         m_bgfill+=5;
         QTimer::singleShot(10, this, SLOT(update()));
-        return;
+	return;
     }
     
     m_playAgainButton->setFocus();
@@ -425,7 +428,7 @@ void KHangManView::resizeEvent(QResizeEvent *)
 
     m_playAgainButton->setGeometry( width()/2 - m_playAgainButton->width()/2 , 
                                     height()/2 + m_playAgainButton->height()/2,
-    m_playAgainButton->sizeHint().width(), height()/9 );
+				    m_playAgainButton->sizeHint().width(), height()/9 );
 }
 
 // ----------------------------------------------------------------
@@ -439,7 +442,6 @@ void KHangManView::slotTry()
         m_letterInput->setFocus();
         return;
     }
-    
     kDebug() << "guess as entered: " << guess;
 
     // Handle the guess.
@@ -500,12 +502,12 @@ void KHangManView::slotTry()
         // The letter is already guessed.
 
         // Show a popup that says as much.
-        QPoint point;
+        QPoint point; 
         KPassivePopup *popup = new KPassivePopup( this );
         popup->setPopupStyle( KPassivePopup::Balloon );
         popup->setAutoDelete( true );
         popup->setTimeout( Prefs::missedTimer()*1000 );
-        popup->setView("KHangMan", i18n("This letter has already been guessed.") );
+        popup->setView(i18n("KHangMan"), i18n("This letter has already been guessed.") );
 
         int  x = 0;
         int  y = 0;
@@ -528,7 +530,7 @@ void KHangManView::slotTry()
 
         if (goodWord.contains(guess) > 0) {
             point = m_theme->goodWordPos(size(), popup->pos());
-
+            
             QTimer::singleShot( Prefs::missedTimer() * 1000,
                                 this, SLOT(enableUserInput()) );
 
@@ -618,9 +620,9 @@ void KHangManView::game()
     kDebug() << "language " << Prefs::selectedLanguage();
     kDebug() << "level "    << Prefs::levelFile();
 
-    m_word = m_randomList[m_randomInt%NumberOfWords].first;
+    m_word = m_randomList[m_randomInt%m_randomList.count()].first;
     m_word = m_word.toLower();
-    m_hint = m_randomList[m_randomInt%NumberOfWords].second;
+    m_hint = m_randomList[m_randomInt%m_randomList.count()].second;
 
     if (m_word.isEmpty()) {
         ++m_randomInt;
@@ -649,9 +651,9 @@ void KHangManView::game()
 
     // 1. Find dashes.
     int posOfFirstDash = m_word.indexOf( "-" );
+    
     if (posOfFirstDash>0) {
         goodWord.replace(2*posOfFirstDash, 1, "-");
-
         int posOfSecondDash = m_word.indexOf( "-", posOfFirstDash+1);
         if (posOfSecondDash>0) {
             goodWord.replace(2*posOfSecondDash, 3, "-");
@@ -663,6 +665,7 @@ void KHangManView::game()
 
     // 2. Find white space.
     m_posFirstSpace = m_word.indexOf( " " );
+    
     if (m_posFirstSpace > 0) {
         goodWord.replace(2*m_posFirstSpace, 1, " ");
         m_posSecondSpace = m_word.indexOf( " ", m_posFirstSpace+1);
@@ -672,12 +675,14 @@ void KHangManView::game()
 
     // 3. Find ·
     int posOfDot = m_word.indexOf( QString::fromUtf8("·") );
+    
     if (posOfDot>0) {
         goodWord.replace(2*posOfDot, 1, QString::fromUtf8("·") );
     }
 
     // 4. Find '
     int posOfApos = m_word.indexOf( "'" );
+    
     if (posOfApos>0) {
         goodWord.replace(2*posOfApos, 1, "'");
     }
@@ -707,8 +712,9 @@ void KHangManView::slotSetWordsSequence()
             // there is one
             hint = m_doc->lesson()->entries(KEduVocLesson::Recursive).value(j)->translation(1)->text();
         }
-
-        m_randomList.append(qMakePair(m_doc->lesson()->entries(KEduVocLesson::Recursive).value(j)->translation(0)->text(), hint));
+        if (!m_doc->lesson()->entries(KEduVocLesson::Recursive).value(j)->translation(0)->text().isEmpty()) {
+            m_randomList.append(qMakePair(m_doc->lesson()->entries(KEduVocLesson::Recursive).value(j)->translation(0)->text(), hint));  
+        }
     }
     //shuffle the list
     randomSequence.randomize(m_randomList);
