@@ -74,12 +74,13 @@ ObjectImp* TriangleB3PType::calc( const Args& parents, const KigDocument& ) cons
     centerofmass3 += point;
     points.push_back( point );
   }
-  return new PolygonImp( 3, points, centerofmass3/3 );
+  // return new PolygonImp( 3, points, centerofmass3/3 );
+  return new FilledPolygonImp( points );
 }
 
 const ObjectImpType* TriangleB3PType::resultId() const
 {
-  return PolygonImp::stype();
+  return FilledPolygonImp::stype();
 }
 
 bool TriangleB3PType::canMove( const ObjectTypeCalcer& o ) const
@@ -171,12 +172,13 @@ ObjectImp* PolygonBNPType::calc( const Args& parents, const KigDocument& ) const
     centerofmassn += point;
     points.push_back( point );
   }
-  return new PolygonImp( npoints, points, centerofmassn/npoints );
+  //return new PolygonImp( npoints, points, centerofmassn/npoints );
+  return new FilledPolygonImp( points );
 }
 
 const ObjectImpType* PolygonBNPType::resultId() const
 {
-  return PolygonImp::stype();
+  return FilledPolygonImp::stype();
 }
 
 const ObjectImpType* PolygonBNPType::impRequirement( const ObjectImp*, const Args& ) const
@@ -246,6 +248,118 @@ std::vector<ObjectCalcer*> PolygonBNPType::movableParents( const ObjectTypeCalce
   return std::vector<ObjectCalcer*>( ret.begin(), ret.end() );
 }
 
+/*
+ * Added by Petr Gajdos <pgajdos@suse.cz>
+ * opened polygon
+ */
+
+KIG_INSTANTIATE_OBJECT_TYPE_INSTANCE( OpenPolygonType )
+
+OpenPolygonType::OpenPolygonType()
+  : ObjectType( "OpenPolygon" )
+{
+}
+
+OpenPolygonType::~OpenPolygonType()
+{
+}
+
+const OpenPolygonType* OpenPolygonType::instance()
+{
+  static const OpenPolygonType s;
+  return &s;
+}
+
+ObjectImp* OpenPolygonType::calc( const Args& parents, const KigDocument& ) const
+{
+  uint count = parents.size();
+  assert (count >= 3);
+  std::vector<Coordinate> points;
+
+  uint npoints = 0;
+  for ( uint i = 0; i < count; ++i )
+  {
+    npoints++;
+    if ( ! parents[i]->inherits( PointImp::stype() ) ) return new InvalidImp;
+    Coordinate point = static_cast<const PointImp*>( parents[i] )->coordinate();
+    points.push_back( point );
+  }
+  return new OpenPolygonalImp( points );  // minside = false, mopen = true
+}
+
+const ObjectImpType* OpenPolygonType::resultId() const
+{
+  return OpenPolygonalImp::stype();
+}
+
+const ObjectImpType* OpenPolygonType::impRequirement( const ObjectImp*, const Args& ) const
+{
+  return PointImp::stype();
+}
+
+bool OpenPolygonType::isDefinedOnOrThrough( const ObjectImp*, const Args& ) const
+{
+  return true;
+}
+
+std::vector<ObjectCalcer*> OpenPolygonType::sortArgs( const std::vector<ObjectCalcer*>& args ) const
+{
+  return args;  /* should already be in correct order */
+}
+
+Args OpenPolygonType::sortArgs( const Args& args ) const
+{
+  return args;
+}
+
+bool OpenPolygonType::canMove( const ObjectTypeCalcer& o ) const
+{
+  return isFreelyTranslatable( o );
+}
+
+bool OpenPolygonType::isFreelyTranslatable( const ObjectTypeCalcer& o ) const
+{
+  std::vector<ObjectCalcer*> parents = o.parents();
+  for ( uint i = 0; i < parents.size(); ++i )
+  {
+    if ( !parents[i]->isFreelyTranslatable() ) return false;
+  }
+  return true;
+}
+
+void OpenPolygonType::move( ObjectTypeCalcer& o, const Coordinate& to,
+                         const KigDocument& d ) const
+{
+  std::vector<ObjectCalcer*> parents = o.parents();
+  const Coordinate ref = static_cast<const PointImp*>( parents[0]->imp() )->coordinate();
+  for ( uint i = 0; i < parents.size(); ++i )
+  {
+     const Coordinate a = static_cast<const PointImp*>( parents[i]->imp() )->coordinate();
+     parents[i]->move( to + a - ref, d );
+  }
+}
+
+const Coordinate OpenPolygonType::moveReferencePoint( const ObjectTypeCalcer& o
+) const
+{
+  std::vector<ObjectCalcer*> parents = o.parents();
+  return static_cast<const PointImp*>( parents[0]->imp() )->coordinate();
+}
+
+std::vector<ObjectCalcer*> OpenPolygonType::movableParents( const ObjectTypeCalcer& ourobj ) const
+{
+  std::vector<ObjectCalcer*> parents = ourobj.parents();
+  std::set<ObjectCalcer*> ret;
+  for ( uint i = 0; i < parents.size(); ++i )
+  {
+    std::vector<ObjectCalcer*> tmp = parents[i]->movableParents();
+    ret.insert( tmp.begin(), tmp.end() );
+  }
+  ret.insert( parents.begin(), parents.end() );
+  return std::vector<ObjectCalcer*>( ret.begin(), ret.end() );
+}
+
+
 /*
  * regular polygon by center and vertex
  */
@@ -304,7 +418,8 @@ ObjectImp* PolygonBCVType::calc( const Args& parents, const KigDocument& ) const
                                          stheta1*dx + ctheta1*dy );
     vertexes.push_back( v1 );
   }
-  return new PolygonImp( uint (sides), vertexes, center );
+  //return new PolygonImp( uint (sides), vertexes, center );
+  return new FilledPolygonImp( vertexes );
 }
 
 const ObjectImpType* PolygonBCVType::resultId() const
@@ -389,7 +504,7 @@ std::vector<ObjectCalcer*> PolygonBCVType::movableParents( const ObjectTypeCalce
 
 static const ArgsParser::spec argsspecPolygonLineIntersection[] =
 {
-  { PolygonImp::stype(), I18N_NOOP( "Intersect this polygon with a line" ),
+  { FilledPolygonImp::stype(), I18N_NOOP( "Intersect this polygon with a line" ),
     I18N_NOOP( "Select the polygon of which you want the intersection with a line..." ), false },
   { AbstractLineImp::stype(), 
     I18N_NOOP( "Intersect this line with a polygon" ), 
@@ -403,6 +518,13 @@ PolygonLineIntersectionType::PolygonLineIntersectionType()
 {
 }
 
+PolygonLineIntersectionType::PolygonLineIntersectionType( const char fulltypename[],
+                        const struct ArgsParser::spec argsspec[],
+                        int n )
+  : ArgsParserObjectType( fulltypename, argsspec, n )
+{
+}
+
 PolygonLineIntersectionType::~PolygonLineIntersectionType()
 {
 }
@@ -413,6 +535,11 @@ const PolygonLineIntersectionType* PolygonLineIntersectionType::instance()
   return &t;
 }
 
+const ObjectImpType* PolygonLineIntersectionType::resultId() const
+{
+  return SegmentImp::stype();
+}
+
 /*
  * Intersection of a polygon and a line/ray/segment.
  *
@@ -435,13 +562,16 @@ ObjectImp* PolygonLineIntersectionType::calc( const Args& parents, const KigDocu
 {
   if ( ! margsparser.checkArgs( parents ) ) return new InvalidImp;
 
-  const PolygonImp* polygon = static_cast<const PolygonImp*>( parents[0] );
+  const AbstractPolygonImp* polygon = static_cast<const AbstractPolygonImp*>( parents[0] );
   const std::vector<Coordinate> ppoints = polygon->points();
   const LineData line = static_cast<const AbstractLineImp*>( parents[1] )->data();
   double t1, t2;
+  int side = 0;
   uint numintersections;
   std::vector<Coordinate>::const_iterator intersectionside;
 
+  // since we use the same constructor as for ConicLine, we get the values -1 and +1
+  if ( parents.size() >= 3 ) side = static_cast<const IntImp*>( parents[2] )->data();
   bool boundleft = false;
   bool boundright = false;
   if ( parents[1]->inherits( SegmentImp::stype() ) )
@@ -453,8 +583,23 @@ ObjectImp* PolygonLineIntersectionType::calc( const Args& parents, const KigDocu
     boundleft = true;
   } 
 
+  bool openpolygon = false;
+  bool inside = false;
+  if ( parents[0]->inherits( OpenPolygonalImp::stype() ) ) openpolygon = true;
+  if ( parents[0]->inherits( FilledPolygonImp::stype() ) ) inside = true;
+
   numintersections = polygonlineintersection( ppoints, line.a, line.b,
-                         boundleft, boundright, t1, t2, intersectionside );
+                         boundleft, boundright, inside, openpolygon, t1, t2, intersectionside );
+
+  bool filledpolygon = false;
+  if ( parents[0]->inherits( FilledPolygonImp::stype() ) ) filledpolygon = true;
+
+  if ( ! filledpolygon )
+  {
+    if ( side ==  -1 && numintersections >= 1) return new PointImp( line.a + t1*(line.b - line.a) );
+    if ( side == 1 && numintersections >= 2) return new PointImp( line.a + t2*(line.b - line.a) );
+    return new InvalidImp;
+  } 
 
   if (numintersections > 2) return new InvalidImp;
 
@@ -471,6 +616,75 @@ ObjectImp* PolygonLineIntersectionType::calc( const Args& parents, const KigDocu
   return new InvalidImp;
 }
 
+/*
+ * polygonal-line intersection, this has an extra parameter
+ * indicating which intersection point we want
+ */
+
+static const ArgsParser::spec argsspecOPolygonalLineIntersection[] =
+{
+  { OpenPolygonalImp::stype(), I18N_NOOP( "Intersect this polygonal with a line" ),
+    I18N_NOOP( "Select the polygonal of which you want the intersection with a line..." ), false },
+  { AbstractLineImp::stype(),
+    I18N_NOOP( "Intersect this line with a polygonal" ),
+    I18N_NOOP( "Select the line of which you want the intersection with a polygonal..." ), false },
+  { IntImp::stype(), "param", "SHOULD NOT BE SEEN", false }
+};
+
+KIG_INSTANTIATE_OBJECT_TYPE_INSTANCE( OPolygonalLineIntersectionType )
+
+OPolygonalLineIntersectionType::OPolygonalLineIntersectionType()
+  : PolygonLineIntersectionType( "OPolygonalLineIntersection", argsspecOPolygonalLineIntersection, 3 )
+{
+}
+
+OPolygonalLineIntersectionType::~OPolygonalLineIntersectionType()
+{
+}
+
+const OPolygonalLineIntersectionType* OPolygonalLineIntersectionType::instance()
+{
+  static const OPolygonalLineIntersectionType t;
+  return &t;
+}
+
+const ObjectImpType* OPolygonalLineIntersectionType::resultId() const
+{
+  return PointImp::stype();
+}
+
+static const ArgsParser::spec argsspecCPolygonalLineIntersection[] =
+{
+  { ClosedPolygonalImp::stype(), I18N_NOOP( "Intersect this polygonal with a line" ),
+    I18N_NOOP( "Select the polygonal of which you want the intersection with a line..." ), false },
+  { AbstractLineImp::stype(),
+    I18N_NOOP( "Intersect this line with a polygonal" ),
+    I18N_NOOP( "Select the line of which you want the intersection with a polygonal..." ), false },
+  { IntImp::stype(), "param", "SHOULD NOT BE SEEN", false }
+};
+
+KIG_INSTANTIATE_OBJECT_TYPE_INSTANCE( CPolygonalLineIntersectionType )
+
+CPolygonalLineIntersectionType::CPolygonalLineIntersectionType()
+  : PolygonLineIntersectionType( "CPolygonalLineIntersection", argsspecCPolygonalLineIntersection, 3 )
+{
+}
+
+CPolygonalLineIntersectionType::~CPolygonalLineIntersectionType()
+{
+}
+
+const CPolygonalLineIntersectionType* CPolygonalLineIntersectionType::instance()
+{
+  static const CPolygonalLineIntersectionType t;
+  return &t;
+}
+
+const ObjectImpType* CPolygonalLineIntersectionType::resultId() const
+{
+  return PointImp::stype();
+}
+
 /*
  * this function computes the intersection of a polygon (given its
  * list of vertices) with a line/ray/segment described by two points;
@@ -497,7 +711,8 @@ ObjectImp* PolygonLineIntersectionType::calc( const Args& parents, const KigDocu
 int
 polygonlineintersection( const std::vector<Coordinate>& ppoints, 
                          const Coordinate a, const Coordinate b,
-                         bool boundleft, bool boundright, double& t1, double& t2,
+                         bool boundleft, bool boundright, bool inside,
+			 bool openpolygon, double& t1, double& t2,
                          std::vector<Coordinate>::const_iterator& intersectionside )
 {
   double intersections[2] = {0.0, 0.0};
@@ -512,9 +727,11 @@ polygonlineintersection( const std::vector<Coordinate>& ppoints,
   bool leftendinside = false;
   bool rightendinside = false;
   Coordinate prevpoint = ppoints.back() - a;
+  if ( openpolygon ) prevpoint = ppoints.front() - a;
   bool prevpointbelow = ( abx*prevpoint.y <= aby*prevpoint.x );
   for ( i = ppoints.begin(); i != ppoints.end(); ++i )
   {
+    if ( openpolygon && i == ppoints.begin() ) continue;
     Coordinate point = *i - a;
     bool pointbelow = ( abx*point.y <= aby*point.x );
     if ( pointbelow != prevpointbelow ) 
@@ -557,24 +774,26 @@ polygonlineintersection( const std::vector<Coordinate>& ppoints,
     prevpointbelow = pointbelow;
   }
 
-  if ( leftendinside )
+  if ( inside )
   {
-    numintersections++;
-    intersections[1] = intersections[0];
-    intersectionsides[1] = intersectionsides[0];
-    intersections[0] = 0.0;
-    intersectionsides[0] = ppoints.end();
-  }
-
-  if ( rightendinside )
-  {
-    numintersections++;
-    intersections[1] = 1.0;
-    intersectionsides[1] = ppoints.end();
-    if ( numintersections < 2 )
+    if ( leftendinside )
     {
-      intersections[0] = 1.0;
+      numintersections++;
+      intersections[1] = intersections[0];
+      intersectionsides[1] = intersectionsides[0];
+      intersections[0] = 0.0;
+      intersectionsides[0] = ppoints.end();
+    }
+    if ( rightendinside )
+    {
+      numintersections++;
+      intersections[1] = 1.0;
       intersectionsides[1] = ppoints.end();
+      if ( numintersections < 2 )
+      {
+        intersections[0] = 1.0;
+        intersectionsides[1] = ppoints.end();
+      }
     }
   }
 
@@ -593,18 +812,22 @@ polygonlineintersection( const std::vector<Coordinate>& ppoints,
   return numintersections;
 }
 
-const ObjectImpType* PolygonLineIntersectionType::resultId() const
+int
+polygonlineintersection( const std::vector<Coordinate>& ppoints, 
+                         const Coordinate a, const Coordinate b,
+                         double& t1, double& t2,
+                         std::vector<Coordinate>::const_iterator& intersectionside )
 {
-  return SegmentImp::stype();
+  return polygonlineintersection ( ppoints, a, b, true, true, true, false, t1, t2, intersectionside );
 }
 
 /* polygon-polygon intersection */
 
 static const ArgsParser::spec argsspecPolygonPolygonIntersection[] =
 {
-  { PolygonImp::stype(), I18N_NOOP( "Intersect this polygon with another polygon" ),
+  { FilledPolygonImp::stype(), I18N_NOOP( "Intersect this polygon with another polygon" ),
     I18N_NOOP( "Select the polygon of which you want the intersection with another polygon..." ), false },
-  { PolygonImp::stype(), I18N_NOOP( "Intersect with this polygon" ),
+  { FilledPolygonImp::stype(), I18N_NOOP( "Intersect with this polygon" ),
     I18N_NOOP( "Select the second polygon for the intersection..." ), false }
 };
 
@@ -629,9 +852,9 @@ ObjectImp* PolygonPolygonIntersectionType::calc( const Args& parents, const KigD
 {
   if ( ! margsparser.checkArgs( parents ) ) return new InvalidImp;
 
-  const PolygonImp* polygon1 = static_cast<const PolygonImp*>( parents[0] );
+  const FilledPolygonImp* polygon1 = static_cast<const FilledPolygonImp*>( parents[0] );
   const std::vector<Coordinate> ppoints1 = polygon1->points();
-  const PolygonImp* polygon2 = static_cast<const PolygonImp*>( parents[1] );
+  const FilledPolygonImp* polygon2 = static_cast<const FilledPolygonImp*>( parents[1] );
   const std::vector<Coordinate> ppoints2 = polygon2->points();
   std::vector<Coordinate> ppointsint;
   double t1, t2;
@@ -655,7 +878,7 @@ ObjectImp* PolygonPolygonIntersectionType::calc( const Args& parents, const KigD
     for (ipoint = ppointsa->begin(); ipoint != ppointsa->end(); ++ipoint)
     {
       numintersections = polygonlineintersection( *ppointsb, 
-                           *iprevpoint, *ipoint, true, true, t1, t2, intersectionside);
+                           *iprevpoint, *ipoint, t1, t2, intersectionside);
       if (numintersections >= 2)
       {
         intersect = true;
@@ -689,7 +912,7 @@ ObjectImp* PolygonPolygonIntersectionType::calc( const Args& parents, const KigD
       ipoint += direction;
       if ( ipoint == ppointsa->end() ) ipoint = ppointsa->begin();
       numintersections = polygonlineintersection( *ppointsb, 
-                           *iprevpoint, *ipoint, true, true, t1, t2, intersectionside);
+                           *iprevpoint, *ipoint, t1, t2, intersectionside);
       if ( numintersections < 2 )
       {
         /*
@@ -701,7 +924,7 @@ ObjectImp* PolygonPolygonIntersectionType::calc( const Args& parents, const KigD
          */
         point = 1e-10*(*iprevprevpoint) + (1 - 1e-10)*(*iprevpoint);
         numintersections = polygonlineintersection( *ppointsb, 
-                             point, *ipoint, true, true, t1, t2, intersectionside);
+                             point, *ipoint, t1, t2, intersectionside);
       } else
       {
         if ( t1 != 0.0 ) return new InvalidImp;             /* can this happen? */
@@ -722,13 +945,13 @@ ObjectImp* PolygonPolygonIntersectionType::calc( const Args& parents, const KigD
       point = ppointsint.back();
       direction = 1;
       numintersections = polygonlineintersection( *ppointsb, 
-                           point, *ipoint, true, true, t1, t2, intersectionside);
+                           point, *ipoint, t1, t2, intersectionside);
       if ( numintersections < 2 || t2 < 1e-12)
       {
         direction = -1;
         ipoint = iprevpoint;
         numintersections = polygonlineintersection( *ppointsb, 
-                             point, *ipoint, true, true, t1, t2, intersectionside);
+                             point, *ipoint, t1, t2, intersectionside);
         if (numintersections < 2) return new InvalidImp;
       }
       point = point + t2*(*ipoint-point);
@@ -739,19 +962,19 @@ ObjectImp* PolygonPolygonIntersectionType::calc( const Args& parents, const KigD
   if (ppointsint.size() < 2) return new InvalidImp;   /* should never happen */
   ppointsint.pop_back();
   ppointsint.pop_back();
-  return new PolygonImp (ppointsint);
+  return new FilledPolygonImp (ppointsint);
 }
 
 const ObjectImpType* PolygonPolygonIntersectionType::resultId() const
 {
-  return PolygonImp::stype();
+  return FilledPolygonImp::stype();
 }
 
 /* polygon vertices  */
 
 static const ArgsParser::spec argsspecPolygonVertex[] =
 {
-  { PolygonImp::stype(), I18N_NOOP( "Construct the vertices of this polygon" ),
+  { FilledPolygonImp::stype(), I18N_NOOP( "Construct the vertices of this polygon" ),
     I18N_NOOP( "Select the polygon of which you want to construct the vertices..." ), true },
   { IntImp::stype(), "param", "SHOULD NOT BE SEEN", false }
 };
@@ -777,7 +1000,7 @@ ObjectImp* PolygonVertexType::calc( const Args& parents, const KigDocument& ) co
 {
   if ( ! margsparser.checkArgs( parents ) ) return new InvalidImp;
 
-  const std::vector<Coordinate> ppoints = static_cast<const PolygonImp*>( parents[0] )->points();
+  const std::vector<Coordinate> ppoints = static_cast<const FilledPolygonImp*>( parents[0] )->points();
   const uint i = static_cast<const IntImp*>( parents[1] )->data();
 
   if ( i >= ppoints.size() ) return new InvalidImp;
@@ -794,7 +1017,7 @@ const ObjectImpType* PolygonVertexType::resultId() const
 
 static const ArgsParser::spec argsspecPolygonSide[] =
 {
-  { PolygonImp::stype(), I18N_NOOP( "Construct the sides of this polygon" ),
+  { FilledPolygonImp::stype(), I18N_NOOP( "Construct the sides of this polygon" ),
     I18N_NOOP( "Select the polygon of which you want to construct the sides..." ), false },
   { IntImp::stype(), "param", "SHOULD NOT BE SEEN", false }
 };
@@ -820,7 +1043,7 @@ ObjectImp* PolygonSideType::calc( const Args& parents, const KigDocument& ) cons
 {
   if ( ! margsparser.checkArgs( parents ) ) return new InvalidImp;
 
-  const std::vector<Coordinate> ppoints = static_cast<const PolygonImp*>( parents[0] )->points();
+  const std::vector<Coordinate> ppoints = static_cast<const FilledPolygonImp*>( parents[0] )->points();
   const uint i = static_cast<const IntImp*>( parents[1] )->data();
 
   if ( i >= ppoints.size() ) return new InvalidImp;
@@ -840,7 +1063,7 @@ const ObjectImpType* PolygonSideType::resultId() const
 
 static const ArgsParser::spec argsspecConvexHull[] =
 {
-  { PolygonImp::stype(), I18N_NOOP( "Construct the convex hull of this polygon" ),
+  { AbstractPolygonImp::stype(), I18N_NOOP( "Construct the convex hull of this polygon" ),
     I18N_NOOP( "Select the polygon of which you want to construct the convex hull..." ), false }
 };
 
@@ -865,16 +1088,16 @@ ObjectImp* ConvexHullType::calc( const Args& parents, const KigDocument& ) const
 {
   if ( ! margsparser.checkArgs( parents ) ) return new InvalidImp;
 
-  const std::vector<Coordinate> ppoints = static_cast<const PolygonImp*>( parents[0] )->points();
+  const std::vector<Coordinate> ppoints = static_cast<const AbstractPolygonImp*>( parents[0] )->points();
 
   if ( ppoints.size() < 3 ) return new InvalidImp;
 
   std::vector<Coordinate> hull = computeConvexHull( ppoints );
   if ( hull.size() < 3 ) return new InvalidImp;
-  return new PolygonImp( hull );
+  return new FilledPolygonImp( hull );
 }
 
 const ObjectImpType* ConvexHullType::resultId() const
 {
-  return PolygonImp::stype();
+  return FilledPolygonImp::stype();
 }
