@@ -29,12 +29,15 @@
 #include "../modes/dragrectmode.h"
 #include "../objects/bogus_imp.h"
 #include "../objects/object_imp.h"
+#include "../objects/object_factory.h"
 
+#include <qbytearray.h>
 #include <qlabel.h>
 #include <qpushbutton.h>
 
 #include <kcursor.h>
-#include <kiconloader.h>
+#include <kdialog.h>
+#include <kicon.h>
 #include <kmessagebox.h>
 
 void ScriptModeBase::dragRect( const QPoint& p, KigWidget& w )
@@ -91,7 +94,7 @@ void ScriptModeBase::mouseMoved( const std::vector<ObjectHolder*>& os,
   w.updateCurPix();
   if ( os.empty() )
   {
-    w.setCursor( KCursor::arrowCursor() );
+    w.setCursor( Qt::ArrowCursor );
     mdoc.emitStatusBarText( 0 );
     w.updateWidget();
   }
@@ -100,7 +103,7 @@ void ScriptModeBase::mouseMoved( const std::vector<ObjectHolder*>& os,
     // the cursor is over an object, show object type next to cursor
     // and set statusbar text
 
-    w.setCursor( KCursor::handCursor() );
+    w.setCursor( Qt::PointingHandCursor );
     QString selectstat = os.front()->selectStatement();
 
     // statusbar text
@@ -120,7 +123,7 @@ ScriptModeBase::ScriptModeBase( KigPart& doc )
   : BaseMode( doc ), mwizard( 0 ), mpart( doc ),
     mwawd( SelectingArgs )
 {
-  mwizard = new NewScriptWizard( doc.widget(), this );
+  mwizard = new NewScriptWizard( doc.widget(), this, doc.iconLoader() );
 
   doc.redrawScreen();
 }
@@ -160,7 +163,6 @@ void ScriptModeBase::codePageEntered()
     QString tempcode = ScriptType::templateCode( mtype, margs );
     mwizard->setText( tempcode );
   };
-  mwizard->setFinishEnabled( mwizard->mpcode, true );
   mwawd = EnteringCode;
   mdoc.redrawScreen();
 }
@@ -198,13 +200,13 @@ bool ScriptCreationMode::queryFinish()
   if ( reto->imp()->inherits( InvalidImp::stype() ) )
   {
     PythonScripter* inst = PythonScripter::instance();
-    QCString errtrace = inst->lastErrorExceptionTraceback().c_str();
+    QByteArray errtrace = inst->lastErrorExceptionTraceback().c_str();
     if ( inst->errorOccurred() )
     {
       KMessageBox::detailedSorry(
         mwizard, i18n( "The Python interpreter caught an error during the execution of your "
                        "script. Please fix the script and click the Finish button again." ),
-        i18n( "The Python Interpreter generated the following error output:\n%1").arg( errtrace ) );
+        i18n( "The Python Interpreter generated the following error output:\n%1", QString( errtrace ) ) );
     }
     else
     {
@@ -218,7 +220,37 @@ bool ScriptCreationMode::queryFinish()
   }
   else
   {
-    mdoc.addObject( new ObjectHolder( reto.get() ) );
+    if ( reto->imp()->inherits( DoubleImp::stype() ) || 
+         reto->imp()->inherits( IntImp::stype() ) )
+    {
+      /*
+       * if the python script returns a DoubleImp (IntImp) we need a way to let the user
+       * interact with the result.  We do this by adding a text label (located at
+       * the origin) that contains the DoubleImp (IntImp) value.
+       */
+      QString s = QString("%1");
+      Coordinate coord = Coordinate( 0., 0. );
+      bool needframe = false;
+      std::vector<ObjectCalcer*> args;
+      args.push_back( reto.get() );
+      ObjectHolder* label = 0;
+      label = ObjectFactory::instance()->label( s, coord, needframe, args, mdoc.document() );
+      mdoc.addObject( label );
+    } else if ( reto->imp()->inherits( StringImp::stype() ) )
+    {
+      /*
+       * if the python script returns a StringImp we need a way to let the user
+       * interact with the result, see above.
+       */
+      QString s = QString("%1");
+      Coordinate coord = Coordinate( 0., 0. );
+      bool needframe = false;
+      std::vector<ObjectCalcer*> args;
+      args.push_back( reto.get() );
+      ObjectHolder* label = 0;
+      label = ObjectFactory::instance()->label( s, coord, needframe, args, mdoc.document() );
+      mdoc.addObject( label );
+    } else mdoc.addObject( new ObjectHolder( reto.get() ) );
     killMode();
     return true;
   }
@@ -237,11 +269,6 @@ void ScriptModeBase::setScriptType( ScriptType::Type type )
 {
   mtype = type;
   mwizard->setType( mtype );
-  if ( mtype != ScriptType::Unknown )
-  {
-    KIconLoader* il = mpart.instance()->iconLoader();
-    mwizard->setIcon( il->loadIcon( ScriptType::icon( mtype ), KIcon::Small ) );
-  }
 }
 
 void ScriptModeBase::addArgs( const std::vector<ObjectHolder*>& obj, KigWidget& w )
@@ -287,12 +314,11 @@ ScriptEditMode::ScriptEditMode( ObjectTypeCalcer* exec_calc, KigPart& doc )
   // in the editor and aborts the editing
   morigscript = static_cast<const StringImp*>( imp )->data();
 
-  mwizard->setCaption( i18n( "'Edit' is a verb", "Edit Script" ) );
+  mwizard->setWindowTitle( KDialog::makeStandardCaption( i18nc( "'Edit' is a verb", "Edit Script" ) ) );
   mwizard->setText( morigscript );
   mwizard->show();
   mwizard->next();
-  mwizard->backButton()->setEnabled( false );
-  mwizard->finishButton()->setEnabled( true );
+  mwizard->button( QWizard::BackButton )->setEnabled( false );
 }
 
 ScriptEditMode::~ScriptEditMode()
@@ -316,18 +342,18 @@ bool ScriptEditMode::queryFinish()
   if ( mexecuted->imp()->inherits( InvalidImp::stype() ) )
   {
     PythonScripter* inst = PythonScripter::instance();
-    QCString errtrace = inst->lastErrorExceptionTraceback().c_str();
+    QByteArray errtrace = inst->lastErrorExceptionTraceback().c_str();
     if ( inst->errorOccurred() )
     {
       KMessageBox::detailedSorry(
-        mpart.widget(), i18n( "The Python interpreter caught an error during the execution of your "
+        mwizard, i18n( "The Python interpreter caught an error during the execution of your "
                               "script. Please fix the script." ),
-        i18n( "The Python Interpreter generated the following error output:\n%1").arg( errtrace ) );
+        i18n( "The Python Interpreter generated the following error output:\n%1", QString( errtrace ) ) );
     }
     else
     {
       KMessageBox::sorry(
-        mpart.widget(), i18n( "There seems to be an error in your script. The Python interpreter "
+        mwizard, i18n( "There seems to be an error in your script. The Python interpreter "
                               "reported no errors, but the script does not generate "
                               "a valid object. Please fix the script." ) );
     }
@@ -335,7 +361,7 @@ bool ScriptEditMode::queryFinish()
     return false;
   }
 
-  mpart.history()->addCommand( comm );
+  mpart.history()->push( comm );
   mpart.setModified( true );
 
   killMode();
