@@ -24,10 +24,6 @@
 #include <kglobal.h>
 #include <klocale.h>
 
-void dms::setD( const double &x ) {
-    D = x;
-}
-
 void dms::setD(const int &d, const int &m, const int &s, const int &ms) {
     D = (double)abs(d) + ((double)m + ((double)s + (double)ms/1000.)/60.)/60.;
     if (d<0) {D = -1.0*D;}
@@ -201,10 +197,7 @@ int dms::msecond( void ) const {
 
 
 const dms dms::reduce( void ) const {
-    double a = D;
-    while (a<0.0) {a += 360.0;}
-    while (a>=360.0) {a -= 360.0;}
-    return dms( a );
+    return dms( D - 360.0*floor(D/360.0) );
 }
 
 const QString dms::toDMSString(const bool forceSign) const {
