@@ -41,11 +41,12 @@
 
 #include <kstandarddirs.h>
 
+#include "oal/log.h"
+#include "oal/scope.h"
 #include "indimenu.h"
 #include "ui_indihostconf.h"
 #include "devicemanager.h"
 #include "indidevice.h"
-//#include "indi/libs/indicom.h"
 #include "Options.h"
 
 #include "kstars.h"
@@ -75,6 +76,17 @@ DeviceManagerUI::DeviceManagerUI(QWidget *parent) : QFrame(parent)
     connected           = KIcon( "network-connect" );
     disconnected        = KIcon( "network-disconnect" );
 
+    connect(localTreeWidget, SIGNAL(itemDoubleClicked(QTreeWidgetItem*,int)), this, SLOT(makePortEditable(QTreeWidgetItem*,int)));
+
+}
+
+void DeviceManagerUI::makePortEditable(QTreeWidgetItem* selectedItem, int column)
+{
+    // If it's the port column, then make it user-editable
+    if (column == INDIDriver::LOCAL_PORT_COLUMN)
+        selectedItem->setFlags(Qt::ItemIsSelectable|Qt::ItemIsEditable|Qt::ItemIsEnabled);
+
+    localTreeWidget->editItem(selectedItem, INDIDriver::LOCAL_PORT_COLUMN);
 }
 
 INDIDriver::INDIDriver( KStars *_ks )
@@ -84,7 +96,6 @@ INDIDriver::INDIDriver( KStars *_ks )
     currentPort = Options::serverPortStart().toInt()-1;
     lastGroup = NULL;
     lastDevice = NULL;
-    primary_xml = false;
 
     ui = new DeviceManagerUI( this );
     setMainWidget( ui );
@@ -95,9 +106,9 @@ INDIDriver::INDIDriver( KStars *_ks )
     {
         QTreeWidgetItem *item = new QTreeWidgetItem(ui->clientTreeWidget, lastGroup);
         lastGroup = item;
-        item->setIcon(0, ui->disconnected);
-        item->setText(1, host->name);
-        item->setText(2, host->portnumber);
+        item->setIcon(HOST_STATUS_COLUMN, ui->disconnected);
+        item->setText(HOST_NAME_COLUMN, host->name);
+        item->setText(HOST_PORT_COLUMN, host->portnumber);
     }
 
     lastGroup = NULL;
@@ -128,10 +139,11 @@ void INDIDriver::enableDevice(INDI_D *indi_device)
    {
    	foreach (INDIHostsInfo * host, ksw->data()->INDIHostsList)
     	{
+
 	        if (host->deviceManager == indi_device->deviceManager && host->isConnected == false)
 	        {
 	    		foreach (QTreeWidgetItem *item, ui->clientTreeWidget->findItems(host->name, Qt::MatchExactly, 1))
-				item->setIcon(0, ui->connected);
+                                item->setIcon(HOST_STATUS_COLUMN, ui->connected);
 	
              		host->isConnected = true;
 			updateClientTab();
@@ -149,8 +161,8 @@ void INDIDriver::enableDevice(INDI_D *indi_device)
 		{
 			foreach (QTreeWidgetItem *item, ui->localTreeWidget->findItems(device->tree_label, Qt::MatchExactly |  Qt::MatchRecursive))
 			{
-				item->setIcon(1, ui->runningPix);
-        			item->setText(4, QString::number(indi_device->deviceManager->port));
+                                item->setIcon(LOCAL_STATUS_COLUMN, ui->runningPix);
+                                item->setText(LOCAL_PORT_COLUMN, QString::number(indi_device->deviceManager->port));
 			}
 			
 			updateLocalTab();
@@ -175,7 +187,7 @@ void INDIDriver::disableDevice(INDI_D *indi_device)
 	        if (host->deviceManager == indi_device->deviceManager && host->isConnected == true)
 	        {
 	    		foreach (QTreeWidgetItem *item, ui->clientTreeWidget->findItems(host->name, Qt::MatchExactly,1))
-				item->setIcon(0, ui->disconnected);
+                                item->setIcon(HOST_STATUS_COLUMN, ui->disconnected);
 	
 			host->deviceManager = NULL;
 		        host->isConnected = false;
@@ -193,9 +205,9 @@ void INDIDriver::disableDevice(INDI_D *indi_device)
 		{
 			foreach (QTreeWidgetItem *item, ui->localTreeWidget->findItems(device->tree_label, Qt::MatchExactly |  Qt::MatchRecursive))
 			{
-				item->setIcon(1, ui->stopPix);
-            			item->setIcon(2, QIcon());
-            			item->setText(4, QString());
+                                item->setIcon(LOCAL_STATUS_COLUMN, ui->stopPix);
+                                item->setIcon(LOCAL_MODE_COLUMN, QIcon());
+                                item->setText(LOCAL_PORT_COLUMN, device->port);
 			}
 			
 			device->clear();
@@ -236,7 +248,7 @@ void INDIDriver::updateLocalTab()
     foreach (IDevice *device, devices)
       {
   
-        if (ui->localTreeWidget->currentItem()->text(0) == device->tree_label)
+        if (ui->localTreeWidget->currentItem()->text(LOCAL_NAME_COLUMN) == device->tree_label)
           {
             ui->runServiceB->setEnabled(device->state == IDevice::DEV_TERMINATE);
             ui->stopServiceB->setEnabled(device->state == IDevice::DEV_START);
@@ -256,7 +268,7 @@ void INDIDriver::updateClientTab()
 
     foreach (INDIHostsInfo * host, ksw->data()->INDIHostsList)
     {
-        if (ui->clientTreeWidget->currentItem()->text(1) == host->name && ui->clientTreeWidget->currentItem()->text(2) == host->portnumber)
+        if (ui->clientTreeWidget->currentItem()->text(HOST_NAME_COLUMN) == host->name && ui->clientTreeWidget->currentItem()->text(HOST_PORT_COLUMN) == host->portnumber)
         {
             ui->connectHostB->setEnabled(!host->isConnected);
             ui->disconnectHostB->setEnabled(host->isConnected);
@@ -271,24 +283,44 @@ void INDIDriver::processLocalTree(IDevice::DeviceStatus dev_request)
    QList<IDevice *> processed_devices;
    DeviceManager *deviceManager=NULL;
 
+   int port=0;
+   bool portOK=false;
+
    foreach(QTreeWidgetItem *item, ui->localTreeWidget->selectedItems())
    {
       foreach (IDevice *device, devices)
       {
 		//device->state = (dev_request == IDevice::DEV_TERMINATE) ? IDevice::DEV_START : IDevice::DEV_TERMINATE;
-		if (item->text(0) == device->tree_label && device->state != dev_request)
-
+                if (item->text(LOCAL_NAME_COLUMN) == device->tree_label && device->state != dev_request)
+                {
 			processed_devices.append(device);
-      }
+
+                        // N.B. If multipe devices are selected to run under one device manager
+                        // then we select the port for the first device that has a valid port
+                        // entry, the rest are ignored.
+                        if (port == 0 && item->text(LOCAL_PORT_COLUMN).isEmpty() == false)
+                        {
+                            port = item->text(LOCAL_PORT_COLUMN).toInt(&portOK);
+                            // If we encounter conversion error, we abort
+                            if (portOK == false)
+                            {
+                                KMessageBox::error(0, i18n("Invalid port entry: %1", item->text(LOCAL_PORT_COLUMN)));
+                                return;
+                            }
+                        }
+                }
+       }
    }
 
    if (processed_devices.empty()) return;
 
+   // Select random port within range is none specified.
+    port = getINDIPort(port);
+
    if (dev_request == IDevice::DEV_START)
    {
-	int port = getINDIPort();
 
-    	if (port < 0)
+        if (port <= 0)
         {
 	        KMessageBox::error(0, i18n("Cannot start INDI server: port error."));
         	return;
@@ -320,8 +352,8 @@ void INDIDriver::processRemoteTree(IDevice::DeviceStatus dev_request)
      bool toConnect = (dev_request == IDevice::DEV_START);
 
     foreach (INDIHostsInfo * host, ksw->data()->INDIHostsList)
-        //hostInfo = ksw->data()->INDIHostsList.at(i);
-        if (currentItem->text(1) == host->name && currentItem->text(2) == host->portnumber)
+     {
+        if (currentItem->text(HOST_NAME_COLUMN) == host->name && currentItem->text(HOST_PORT_COLUMN) == host->portnumber)
         {
             // Nothing changed, return
             if (host->isConnected == toConnect)
@@ -347,6 +379,7 @@ void INDIDriver::processRemoteTree(IDevice::DeviceStatus dev_request)
   
 		return;
 	  }
+    }
 }
 
 void INDIDriver::newTelescopeDiscovered()
@@ -410,120 +443,6 @@ void INDIDriver::updateMenuActions()
 
 }
 
-void INDIDriver::saveDevicesToDisk()
-{
-
-    QFile file;
-    QString elementData;
-
-    file.setFileName( KStandardDirs::locateLocal( "appdata", "drivers.xml" ) ); //determine filename in local user KDE directory tree.
-
-    if ( !file.open( QIODevice::WriteOnly))
-    {
-        QString message = i18n( "unable to write to file 'drivers.xml'\nAny changes to INDI device drivers will not be saved." );
-        KMessageBox::sorry( 0, message, i18n( "Could Not Open File" ) );
-        return;
-    }
-
-    QTextStream outstream(&file);
-
-    // Next we write devices, in the following order:
-    // Telescopes, CCDs, Filter Wheels, Video, Dome, GPS
-    // #1 Telescopes
-    outstream << "<devGroup group='Telescopes'>" << endl;
-    //for (unsigned i=0; i < devices.size(); i++)
-    foreach (IDevice *dev, devices)
-    {
-	// We only write devices that were contained orignally in drivers.xml
-	if (dev->primary_xml == false)
-		continue;
-
-        if (dev->deviceType == KSTARS_TELESCOPE)
-        {
-//            outstream << QString("<device label='%1' focal_length='%2' aperture='%3'>").arg(dev->tree_label).arg(dev->focal_length > 0 ? dev->focal_length : -1).arg(dev->aperture > 0 ? dev->aperture : -1) << endl;
-
-            outstream << QString("<device label='%1'").arg(dev->tree_label);
-	    if (dev->focal_length > 0)
-	            outstream << QString(" focal_length='%1'").arg(dev->focal_length);
-	    if (dev->aperture > 0)
-	            outstream << QString(" aperture='%1'").arg(dev->aperture);
-	    outstream << QString(">") << endl;
-	
-
-            outstream << "       <driver name='" << dev->driver_class << "'>" << dev->driver << "</driver>" << endl;
-            outstream << "       <version>" << dev->version << "</version>" << endl;
-            outstream << "</device>" << endl;
-        }
-    }
-    outstream << "</devGroup>" << endl;
-
-#ifdef HAVE_CFITSIO_H
-    // #2 CCDs
-    outstream << "<devGroup group='CCDs'>" << endl;
-    //for (unsigned i=0; i < devices.size(); i++)
-    foreach (IDevice *dev, devices)
-    {
-	// We only write devices that were contained orignally in drivers.xml
-	if (dev->primary_xml == false)
-		continue;
-
-        if (dev->deviceType == KSTARS_CCD)
-        {
-            outstream << QString("<device label='%1'>").arg(dev->tree_label) << endl;
-            outstream << "       <driver name='" << dev->driver_class << "'>" << dev->driver << "</driver>" << endl;
-            outstream << "       <version>" << dev->version << "</version>" << endl;
-            outstream << "</device>" << endl;
-        }
-    }
-    outstream << "</devGroup>" << endl;
-#endif
-
-    // #3 Filter wheels
-    outstream << "<devGroup group='Filter Wheels'>" << endl;
-
-    foreach (IDevice *dev, devices)
-    //for (unsigned i=0; i < devices.size(); i++)
-    {
-	// We only write devices that were contained orignally in drivers.xml
-	if (dev->primary_xml == false)
-		continue;
-
-        if (dev->deviceType == KSTARS_FILTER)
-        {
-            outstream << QString("<device label='%1'>").arg(dev->tree_label) << endl;
-            outstream << "       <driver name='" << dev->driver_class << "'>" << dev->driver << "</driver>" << endl;
-            outstream << "       <version>" << dev->version << "</version>" << endl;
-            outstream << "</device>" << endl;
-        }
-    }
-    outstream << "</devGroup>" << endl;
-
-#ifdef HAVE_CFITSIO_H
-    // #4 Video
-    outstream << "<devGroup group='Video'>" << endl;
-
-    foreach (IDevice *dev, devices)
-    //for (unsigned i=0; i < devices.size(); i++)
-    {
-	// We only write devices that were contained orignally in drivers.xml
-	if (dev->primary_xml == false)
-		continue;
-
-        if (dev->deviceType == KSTARS_VIDEO)
-        {
-            outstream << QString("<device label='%1'>").arg(dev->tree_label) << endl;
-            outstream << "       <driver name='" << dev->driver_class << "'>" << dev->driver << "</driver>" << endl;
-            outstream << "       <version>" << dev->version << "</version>" << endl;
-            outstream << "</device>" << endl;
-        }
-    }
-    outstream << "</devGroup>" << endl;
-#endif
-
-    file.close();
-
-}
-
 bool INDIDriver::isDeviceRunning(const QString &deviceLabel)
 {
     foreach(IDevice *dev, devices) {
@@ -533,19 +452,33 @@ bool INDIDriver::isDeviceRunning(const QString &deviceLabel)
     return false;
 }
 
-int INDIDriver::getINDIPort()
+int INDIDriver::getINDIPort(int customPort)
 {
 
     int lastPort  = Options::serverPortEnd().toInt();;
+    bool success = false;
     currentPort++;
 
     // recycle
     if (currentPort > lastPort) currentPort = Options::serverPortStart().toInt();
 
     QTcpServer temp_server;
+
+    if (customPort != 0)
+    {
+        success = temp_server.listen(QHostAddress::LocalHost, customPort);
+        if (success)
+        {
+            temp_server.close();
+            return customPort;
+        }
+        else
+            return -1;
+    }
+
     for(; currentPort <= lastPort; currentPort++)
     {
-        bool success = temp_server.listen(QHostAddress::LocalHost, currentPort);
+            success = temp_server.listen(QHostAddress::LocalHost, currentPort);
         if(success)
         {
             temp_server.close();
@@ -572,6 +505,10 @@ bool INDIDriver::readXMLDrivers()
 
     foreach (QFileInfo fileInfo, list)
     {
+        // libindi 0.7.1: Skip skeleton files
+        if (fileInfo.fileName().endsWith("_sk.xml"))
+            continue;
+
 	if (fileInfo.fileName() == "drivers.xml")
 	{ 
 	    // Let first attempt to load the local version of drivers.xml
@@ -608,7 +545,10 @@ void INDIDriver::processXMLDriver(QString & driverName)
     LilXML *xmlParser = newLilXML();
     XMLEle *root = NULL;
 
-    primary_xml = driverName.endsWith("drivers.xml");
+    if (driverName.endsWith("drivers.xml"))
+        xmlSource = IDevice::PRIMARY_XML;
+    else
+        xmlSource = IDevice::THIRD_PARTY_XML;
 
     while ( file.getChar(&c))
     {
@@ -697,6 +637,7 @@ bool INDIDriver::buildDeviceGroup(XMLEle *root, char errmsg[])
     return true;
 }
 
+
 bool INDIDriver::buildDriverElement(XMLEle *root, QTreeWidgetItem *DGroup, int groupType, char errmsg[])
 {
     XMLAtt *ap;
@@ -706,68 +647,77 @@ bool INDIDriver::buildDriverElement(XMLEle *root, QTreeWidgetItem *DGroup, int g
     QString driver;
     QString version;
     QString name;
+    QString port;
     double focal_length (-1), aperture (-1);
 
-    ap = findXMLAtt(root, "label");
-    if (!ap)
-    {
-        snprintf(errmsg, ERRMSG_SIZE, "Tag %.64s does not have a label attribute", tagXMLEle(root));
-        return false;
-    }
 
-    label = valuXMLAtt(ap);
+        ap = findXMLAtt(root, "label");
+        if (!ap)
+        {
+            snprintf(errmsg, ERRMSG_SIZE, "Tag %.64s does not have a label attribute", tagXMLEle(root));
+            return false;
+        }
 
-    // Let's look for telescope-specific attributes: focal length and aperture
-    ap = findXMLAtt(root, "focal_length");
-    if (ap)
-        focal_length = QString(valuXMLAtt(ap)).toDouble();
+        label = valuXMLAtt(ap);
 
-    ap = findXMLAtt(root, "aperture");
-    if (ap)
-        aperture = QString(valuXMLAtt(ap)).toDouble();
+        // Search for optional port attribute
+        ap = findXMLAtt(root, "port");
+        if (ap)
+            port = valuXMLAtt(ap);
 
-    el = findXMLEle(root, "driver");
+        // Let's look for telescope-specific attributes: focal length and aperture
+        ap = findXMLAtt(root, "focal_length");
+        if (ap)
+            focal_length = QString(valuXMLAtt(ap)).toDouble();
 
-    if (!el)
-        return false;
+        ap = findXMLAtt(root, "aperture");
+        if (ap)
+            aperture = QString(valuXMLAtt(ap)).toDouble();
 
-    driver = pcdataXMLEle(el);
+        el = findXMLEle(root, "driver");
 
-    ap = findXMLAtt(el, "name");
-    if (!ap)
-    {
-        snprintf(errmsg, ERRMSG_SIZE, "Tag %.64s does not have a name attribute", tagXMLEle(el));
-        return false;
-    }
+        if (!el)
+            return false;
 
-    name = valuXMLAtt(ap);
+        driver = pcdataXMLEle(el);
 
-    el = findXMLEle(root, "version");
+        ap = findXMLAtt(el, "name");
+        if (!ap)
+        {
+            snprintf(errmsg, ERRMSG_SIZE, "Tag %.64s does not have a name attribute", tagXMLEle(el));
+            return false;
+        }
 
-    if (!el)
-        return false;
+        name = valuXMLAtt(ap);
 
-  version = pcdataXMLEle(el);
+        el = findXMLEle(root, "version");
 
-    QTreeWidgetItem *device = new QTreeWidgetItem(DGroup, lastDevice);
+        if (!el)
+            return false;
 
-    device->setText(0, QString(label));
-    device->setIcon(1, ui->stopPix);
-    device->setText(3, QString(version));
+        version = pcdataXMLEle(el);
+
+        QTreeWidgetItem *device = new QTreeWidgetItem(DGroup, lastDevice);
+
+    device->setText(LOCAL_NAME_COLUMN, label);
+    device->setIcon(LOCAL_STATUS_COLUMN, ui->stopPix);
+    device->setText(LOCAL_VERSION_COLUMN, version);
+    device->setText(LOCAL_PORT_COLUMN, port);
 
     lastDevice = device;
 
-    if (primary_xml && driversList.contains(driver) == false)
-	driversList << driver;
+    if ((xmlSource == IDevice::PRIMARY_XML) && driversList.contains(driver) == false)
+        driversList.insert(driver, name);
 
     dv = new IDevice(name, label, driver, version);
     dv->deviceType = groupType;
-    dv->primary_xml = primary_xml;
+    dv->xmlSource = xmlSource;
     //connect(dv, SIGNAL(newServerInput()), this, SLOT(updateLocalTab()));
     if (focal_length > 0)
         dv->focal_length = focal_length;
     if (aperture > 0)
         dv->aperture = aperture;
+    dv->port = port;
 
     devices.append(dv);
 
@@ -775,6 +725,83 @@ bool INDIDriver::buildDriverElement(XMLEle *root, QTreeWidgetItem *DGroup, int g
     return true;
 }
 
+void INDIDriver::updateCustomDrivers()
+{
+    QString label;
+    QString driver;
+    QString version;
+    QString name;
+    IDevice *dv;
+    QTreeWidgetItem *group, *widgetDev;
+    double focal_length (-1), aperture (-1);
+
+    // Find if the group already exists
+    QList<QTreeWidgetItem *> treeList = ui->localTreeWidget->findItems("Telescopes", Qt::MatchExactly);
+    if (!treeList.isEmpty())
+        group = treeList[0];
+    else return;
+
+
+        // Find custom telescope to ADD
+    foreach(OAL::Scope *s, *(KStarsData::Instance()->logObject()->scopeList()))
+        {
+            label = s->vendor() + " " + s->model();
+
+            if (s->driver() == i18n("None") || findDeviceByLabel(label))
+                continue;
+
+            QHash<QString, QString>::const_iterator i = driversList.constFind(s->driver());
+            if (i != driversList.constEnd() && i.key() == s->driver())
+                name  = i.value();
+            else
+                return;
+            focal_length = s->focalLength();
+            aperture = s->aperture();
+            driver = s->driver();
+            version = QString("1.0");
+
+            QTreeWidgetItem *device = new QTreeWidgetItem(group, lastDevice);
+            device->setText(LOCAL_NAME_COLUMN, QString(label));
+            device->setIcon(LOCAL_STATUS_COLUMN, ui->stopPix);
+            device->setText(LOCAL_VERSION_COLUMN, QString(version));
+
+            lastDevice = device;
+
+            dv = new IDevice(name, label, driver, version);
+            dv->deviceType = KSTARS_TELESCOPE;
+            dv->xmlSource = IDevice::EM_XML;
+            dv->focal_length = focal_length;
+            dv->aperture = aperture;
+            dv->id = s->id();
+            devices.append(dv);
+        }
+
+        // Find custom telescope to REMOVE
+        foreach(IDevice *dev, devices)
+        {
+            // If it's from primary xml file or it is in a running state, continue.
+            if (dev->xmlSource != IDevice::EM_XML || dev->state == IDevice::DEV_START)
+                continue;
+
+            // See if log object has the device, if not delete it
+            if (KStarsData::Instance()->logObject()->findScopeById(dev->id))
+                continue;
+
+            // Find if the group already exists
+            QList<QTreeWidgetItem *> devList = ui->localTreeWidget->findItems(dev->tree_label, Qt::MatchExactly  | Qt::MatchRecursive);
+            if (!devList.isEmpty())
+            {
+                widgetDev = devList[0];
+                group->removeChild(widgetDev);
+            }
+            else return;
+
+            devices.removeOne(dev);
+            delete (dev);
+        }
+
+}
+
 void INDIDriver::addINDIHost()
 {
     QDialog hostConfDialog;
@@ -814,9 +841,9 @@ void INDIDriver::addINDIHost()
         ksw->data()->INDIHostsList.append(hostItem);
 
         QTreeWidgetItem *item = new QTreeWidgetItem(ui->clientTreeWidget);
-        item->setIcon(0, ui->disconnected);
-        item->setText(1, hostConf.nameIN->text());
-        item->setText(2, hostConf.portnumber->text());
+        item->setIcon(HOST_STATUS_COLUMN, ui->disconnected);
+        item->setText(HOST_NAME_COLUMN, hostConf.nameIN->text());
+        item->setText(HOST_PORT_COLUMN, hostConf.portnumber->text());
 
     }
 
@@ -840,7 +867,7 @@ void INDIDriver::modifyINDIHost()
 
     foreach (INDIHostsInfo * host, ksw->data()->INDIHostsList)
     {
-        if (currentItem->text(1) == host->name && currentItem->text(2) == host->portnumber)
+        if (currentItem->text(HOST_NAME_COLUMN) == host->name && currentItem->text(HOST_PORT_COLUMN) == host->portnumber)
         {
             hostConf.nameIN->setText(host->name);
             hostConf.hostname->setText(host->hostname);
@@ -853,8 +880,8 @@ void INDIDriver::modifyINDIHost()
                 host->hostname   = hostConf.hostname->text();
                 host->portnumber = hostConf.portnumber->text();
 
-                currentItem->setText(1, hostConf.nameIN->text());
-                currentItem->setText(2, hostConf.portnumber->text());
+                currentItem->setText(HOST_NAME_COLUMN, hostConf.nameIN->text());
+                currentItem->setText(HOST_PORT_COLUMN, hostConf.portnumber->text());
 
                 //ksw->data()->INDIHostsList.replace(i, hostItem);
 
@@ -873,8 +900,8 @@ void INDIDriver::removeINDIHost()
         return;
 
     for (int i=0; i < ksw->data()->INDIHostsList.count(); i++)
-        if (ui->clientTreeWidget->currentItem()->text(1) == ksw->data()->INDIHostsList[i]->name &&
-                ui->clientTreeWidget->currentItem()->text(2) == ksw->data()->INDIHostsList[i]->portnumber)
+        if (ui->clientTreeWidget->currentItem()->text(HOST_NAME_COLUMN) == ksw->data()->INDIHostsList[i]->name &&
+                ui->clientTreeWidget->currentItem()->text(HOST_PORT_COLUMN) == ksw->data()->INDIHostsList[i]->portnumber)
         {
             if (ksw->data()->INDIHostsList[i]->isConnected)
             {
@@ -882,7 +909,7 @@ void INDIDriver::removeINDIHost()
                 return;
             }
 
-            if (KMessageBox::warningContinueCancel( 0, i18n("Are you sure you want to remove the %1 client?", ui->clientTreeWidget->currentItem()->text(1)), i18n("Delete Confirmation"),KStandardGuiItem::del())!=KMessageBox::Continue)
+            if (KMessageBox::warningContinueCancel( 0, i18n("Are you sure you want to remove the %1 client?", ui->clientTreeWidget->currentItem()->text(HOST_NAME_COLUMN)), i18n("Delete Confirmation"),KStandardGuiItem::del())!=KMessageBox::Continue)
                 return;
 
             delete ksw->data()->INDIHostsList.takeAt(i);
@@ -932,6 +959,15 @@ void INDIDriver::saveHosts()
 
 }
 
+IDevice * INDIDriver::findDeviceByLabel(const QString &label)
+{
+    foreach(IDevice *dev, devices)
+        if (dev->tree_label == label)
+            return dev;
+
+    return NULL;
+}
+
 INDIDriver::~INDIDriver()
 {
 
@@ -944,13 +980,13 @@ INDIDriver::~INDIDriver()
 
 IDevice::IDevice(const QString &inName, const QString &inLabel, const QString &inDriver, const QString &inVersion)
 {
-    tree_label	 = inLabel;;
+    tree_label	 = inLabel;
     unique_label.clear();
     driver_class = inName;
     driver	 = inDriver;
     version	 = inVersion;
 
-    primary_xml  = false;
+    xmlSource  = PRIMARY_XML;
   
       // Initially off
     state = IDevice::DEV_TERMINATE;
