@@ -23,8 +23,8 @@
 #include <config-kstars.h>
 
 #include "tools/observinglist.h"
-#include "comast/equipmentwriter.h"
-#include "comast/observeradd.h"
+#include "oal/equipmentwriter.h"
+#include "oal/observeradd.h"
 
 // forward declaration is enough. We only need pointers
 class QPalette;
@@ -500,9 +500,6 @@ private slots:
     /** action slot: open Telescope wizard */
     void slotTelescopeWizard();
 
-    /** action slot: open Telescope wizard */
-    void slotTelescopeProperties();
-
     /** action slot: open Image Sequence dialog */
     void slotImageSequence();
 
