@@ -17,8 +17,6 @@
 
 #include "equator.h"
 
-#include <QPainter>
-
 #include "ksnumbers.h"
 #include "kstarsdata.h"
 #include "skymap.h"
@@ -26,47 +24,26 @@
 #include "dms.h"
 #include "Options.h"
 #include "linelist.h"
+#include "skylabeler.h"
 
-Equator::Equator(SkyComponent *parent ) :
+#include "skypainter.h"
+
+Equator::Equator(SkyComposite *parent ) :
         NoPrecessIndex( parent, i18n("Equator") ),
         m_label( LineListIndex::name() )
-{}
-
-bool Equator::selected()
-{
-    return Options::showEquator();
-}
-
-void Equator::preDraw( QPainter &psky )
-{
-    KStarsData *data = KStarsData::Instance();
-    QColor color( data->colorScheme()->colorNamed( "EqColor" ) );
-    psky.setPen( QPen( QBrush( color ), 1, Qt::SolidLine ) );
-
-    m_label.reset( psky );
-}
-
-void Equator::draw( QPainter &psky )
-{
-    NoPrecessIndex::draw( psky );
-    m_label.draw( psky );
-}
-
-void Equator::init()
 {
     KStarsData *data = KStarsData::Instance();
     KSNumbers num( data->ut().djd() );
 
-    double eps    =   0.1;
-    double minRa  =   0.0;
-    double maxRa  =  23.0;
-    double dRa    =   2.0;
-    double dRa2   =  .5 / 5.;
-    double ra, ra2;
+    const double eps    =   0.1;
+    const double minRa  =   0.0;
+    const double maxRa  =  23.0;
+    const double dRa    =   2.0;
+    const double dRa2   =  .5 / 5.;
 
-    for ( ra = minRa; ra < maxRa; ra += dRa ) {
+    for(double ra = minRa; ra < maxRa; ra += dRa ) {
         LineList* lineList = new LineList();
-        for ( ra2 = ra; ra2 <= ra + dRa + eps; ra2 += dRa2 ) {
+        for(double ra2 = ra; ra2 <= ra + dRa + eps; ra2 += dRa2 ) {
             SkyPoint* o = new SkyPoint( ra2, 0.0 );
             o->EquatorialToHorizontal( data->lst(), data->geo()->lat() );
             lineList->append( o );
@@ -75,17 +52,26 @@ void Equator::init()
     }
 }
 
-
-void Equator::drawLabel( QPainter& psky )
+bool Equator::selected()
 {
-    KStarsData *data = KStarsData::Instance();
-
-    if ( ! selected() ) return;
-
-    QColor color( data->colorScheme()->colorNamed( "EqColor" ) );
-    psky.setPen( QPen( QBrush( color ), 1, Qt::SolidLine ) );
-
-    m_label.draw( psky );
+    return Options::showEquator();
 }
 
+void Equator::preDraw( SkyPainter *skyp )
+{
+    KStarsData *data = KStarsData::Instance();
+    QColor color( data->colorScheme()->colorNamed( "EqColor" ) );
+    skyp->setPen( QPen( QBrush( color ), 1, Qt::SolidLine ) );
+}
+
+void Equator::draw( SkyPainter *skyp )
+{
+    m_label.reset();
+    NoPrecessIndex::draw( skyp );
+
+    KStarsData *data = KStarsData::Instance();
+    QColor color( data->colorScheme()->colorNamed( "EqColor" ) );
+    SkyLabeler::Instance()->setPen( QPen( QBrush( color ), 1, Qt::SolidLine ) );
+    m_label.draw();
+}
 
