@@ -238,10 +238,8 @@ void KSMoon::findPhase() {
     double DegPhase = dms( Phase ).reduce().Degrees();
     iPhase = int( 0.1*DegPhase+0.5 ) % 36; // iPhase must be in [0,36) range
 
-    QString textureName = QString("moon%1").arg(iPhase,2,10,QChar('0'));
-    qDebug() << textureName;
-
-    m_tex = TextureManager::getTexture(textureName);
+    m_tex = TextureManager::getTexture(
+        QString("moon%1").arg(iPhase,2,10,QChar('0')));
 }
 
 QString KSMoon::phaseName() const {
