@@ -107,7 +107,7 @@ public:
     enum TYPE { STAR=0, CATALOG_STAR=1, PLANET=2, OPEN_CLUSTER=3, GLOBULAR_CLUSTER=4,
                 GASEOUS_NEBULA=5, PLANETARY_NEBULA=6, SUPERNOVA_REMNANT=7, GALAXY=8,
                 COMET=9, ASTEROID=10, CONSTELLATION=11, MOON=12, ASTERISM=13, 
-                GALAXY_CLUSTER=14, DARK_NEBULA=15, QUASAR=16, MULT_STAR=17, TYPE_UNKNOWN };
+                GALAXY_CLUSTER=14, DARK_NEBULA=15, QUASAR=16, MULT_STAR=17, RADIO_SOURCE=18, TYPE_UNKNOWN };
 
     /**
      *@return object's primary name.
@@ -119,28 +119,12 @@ public:
      */
     inline QString translatedName() const { return i18n( name().toUtf8() );}
 
-    /**
-     *Set the object's primary name.
-     *@param name the object's primary name
-     */
-    inline void setName( const QString &name ) { Name = name; }
-
-    /**
-     *@return object's secondary name
-     */
+    /** @return object's secondary name */
     inline QString name2( void ) const { return ( hasName2() ? Name2 : emptyString ); }
 
-    /**
-     *@return object's secondary name, translated to local language.
-     */
+    /** @return object's secondary name, translated to local language. */
     inline QString translatedName2() const { return ( hasName2() ? i18n( Name2.toUtf8() ): emptyString );}
 
-    /**
-     *Set the object's secondary name.
-     *@param name2 the object's secondary name.
-     */
-    inline void setName2( const QString &name2=QString() ) { Name2 = name2; }
-
     /**
      *@return object's common (long) name
      */
@@ -187,12 +171,6 @@ public:
      */
     inline float mag( void ) const { return Magnitude; }
 
-    /**
-     *Set the object's magnitude.
-     *@param m the object's magnitude.
-     */
-    inline void setMag( float m ) { Magnitude = m; }
-
     /**
      *@return the object's position angle.  This is overridden in KSPlanetBase
      *and DeepSkyObject; for all other SkyObjects, this returns 0.0.
@@ -204,13 +182,9 @@ public:
      */
     inline bool isSolarSystem() { return ( type() == 2 || type() == 9 || type() == 10 || type() == 12 ); }
 
-    /**
-     *Show Type-specific popup menu.  This is a two-line function that needs to be
-     *overloaded by each subclass of SkyObject, to make sure that the correct popupmenu 
-     *function gets called.  By overloading the function, we don't have to check the 
-     *object type when we need the menu.
+    /** Show Type-specific popup menu. Oveloading is done in the function initPopupMenu
      */
-    virtual void showPopupMenu( KSPopupMenu *pmenu, const QPoint &pos );
+    void showPopupMenu( KSPopupMenu *pmenu, const QPoint &pos );
 
     /**
      *Determine the time at which the point will rise or set.  Because solar system
@@ -237,15 +211,6 @@ public:
      */
     QTime riseSetTimeUT( const KStarsDateTime &dt, const GeoLocation *geo, bool rst, bool exact=true );
 
-    /**
-     *@return the LST time when the object will rise or set
-     *@param dt  target date/time
-     *@param geo pointer to Geographic location
-     *@param rst Boolean. If true will compute rise time. If false
-     *       will compute set time.
-     */
-    dms riseSetTimeLST( const KStarsDateTime &dt, const GeoLocation *geo, bool rst);
-
     /**
      *@return the Azimuth time when the object will rise or set. This function
      *recomputes set or rise UT times.
@@ -303,24 +268,6 @@ public:
       */
     void saveUserLog( const QString &newLog );
 
-    /**
-     *@short draw the object's name label on the map, if it will not overlap with 
-     *existing labels.
-     *@param psky reference to the QPainter on which to draw (either the sky pixmap or printer device)
-     *@param p The screen position for the label (in pixels; typically as found by SkyMap::toScreen())
-     *@param drawBox If true, the bounding box of the label will be drawn on the map.
-     *@note overridden in StarObject
-     */
-    virtual void drawNameLabel( QPainter &psky, const QPointF &p );
-
-    /**
-     *@short draw the object's name label on the map, without checking for
-     *overlap with other labels.
-     *@param psky reference to the QPainter on which to draw (either the sky pixmap or printer device)
-     *@param p The screen position for the label (in pixels; typically as found by SkyMap::toScreen())
-     */
-    virtual void drawRudeNameLabel( QPainter &psky, const QPointF &p );
-
     /**
      *@return the pixel distance for offseting the object's name label
      *@note overridden in StarObject, DeepSkyObject, KSPlanetBase
@@ -370,6 +317,11 @@ public:
     virtual UID getUID() const;
 
 private:
+    /** Initialize the popup menut. This function should call correct
+     * initialization function in KSPopupMenu. By overloading the
+     * function, we don't have to check the object type when we need
+     * the menu. */
+    virtual void initPopupMenu(KSPopupMenu* pmenu);
 
     /**
      *Compute the UT time when the object will rise or set. It is an auxiliary
@@ -438,6 +390,17 @@ private:
     float Magnitude;
 
 protected:
+    /**Set the object's magnitude.
+     * @param m the object's magnitude. */
+    inline void setMag( float m ) { Magnitude = m; }
+
+    /**Set the object's primary name.
+     * @param name the object's primary name */
+    inline void setName( const QString &name ) { Name = name; }
+
+    /**Set the object's secondary name.
+     * @param name2 the object's secondary name. */
+    inline void setName2( const QString &name2=QString() ) { Name2 = name2; }
 
     QString Name, Name2, LongName;
 
