@@ -35,9 +35,6 @@
 
 #include "skycomponents/skylabeler.h"
 
-QMap<QString, QColor> StarObject::ColorMap;
-QHash<QString, QPixmap> StarObject::StarImage;
-
 // DEBUG EDIT. Uncomment for testing Proper Motion
 // You will also need to uncomment all related blocks
 // from this file, starobject.h and also the trixel-boundaries
@@ -64,10 +61,8 @@ StarObject::StarObject( dms r, dms d, float m,
         : SkyObject (SkyObject::STAR, r, d, m, n, n2, QString()),
           PM_RA(pmra), PM_Dec(pmdec),
           Parallax(par), Multiplicity(mult), Variability(var)
-        // SONAME deprecated //, soName( 0 )
 {
-
-    const char *spt = (const char *)sptype.toAscii();
+    QByteArray spt = sptype.toAscii();
     SpType[0] = spt[0];
     SpType[1] = spt[1];
     QString lname;
@@ -93,9 +88,8 @@ StarObject::StarObject( double r, double d, float m,
     : SkyObject (SkyObject::STAR, r, d, m, n, n2, QString()),
       PM_RA(pmra), PM_Dec(pmdec),
       Parallax(par), Multiplicity(mult), Variability(var)
-      // SONAME deprecated //, soName( 0 )
 {
-    const char *spt = (const char *)sptype.toAscii();
+    QByteArray spt = sptype.toAscii();
     SpType[0] = spt[0];
     SpType[1] = spt[1];
     
@@ -238,90 +232,8 @@ void StarObject::setNames( QString name, QString name2 ) {
     setLongName(lname);
 }
 
-
-void StarObject::initImages() {
-    SkyMap *map = SkyMap::Instance();
-    double scale = 1.0;
-    const int starColorIntensity = Options::starColorIntensity();
-
-    if ( map && map->scale() > 1.0 ) scale = map->scale();
-
-    if ( Options::starColorMode() == 0 ) { //Real colors
-        ColorMap.insert( "O", QColor::fromRgb(   0,   0, 255 ) );
-        ColorMap.insert( "B", QColor::fromRgb(   0, 200, 255 ) );
-        ColorMap.insert( "A", QColor::fromRgb(   0, 255, 255 ) );
-        ColorMap.insert( "F", QColor::fromRgb( 200, 255, 100 ) );
-        ColorMap.insert( "G", QColor::fromRgb( 255, 255,   0 ) );
-        ColorMap.insert( "K", QColor::fromRgb( 255, 100,   0 ) );
-        ColorMap.insert( "M", QColor::fromRgb( 255,   0,   0 ) );
-    } else if ( Options::starColorMode() == 1 ) { //Red stars
-        ColorMap.insert( "O", QColor::fromRgb( 255,   0,   0 ) );
-        ColorMap.insert( "B", QColor::fromRgb( 255,   0,   0 ) );
-        ColorMap.insert( "A", QColor::fromRgb( 255,   0,   0 ) );
-        ColorMap.insert( "F", QColor::fromRgb( 255,   0,   0 ) );
-        ColorMap.insert( "G", QColor::fromRgb( 255,   0,   0 ) );
-        ColorMap.insert( "K", QColor::fromRgb( 255,   0,   0 ) );
-        ColorMap.insert( "M", QColor::fromRgb( 255,   0,   0 ) );
-    } else if ( Options::starColorMode() == 2 ) { //Black stars
-        ColorMap.insert( "O", QColor::fromRgb(   0,   0,   0 ) );
-        ColorMap.insert( "B", QColor::fromRgb(   0,   0,   0 ) );
-        ColorMap.insert( "A", QColor::fromRgb(   0,   0,   0 ) );
-        ColorMap.insert( "F", QColor::fromRgb(   0,   0,   0 ) );
-        ColorMap.insert( "G", QColor::fromRgb(   0,   0,   0 ) );
-        ColorMap.insert( "K", QColor::fromRgb(   0,   0,   0 ) );
-        ColorMap.insert( "M", QColor::fromRgb(   0,   0,   0 ) );
-    } else if ( Options::starColorMode() == 3 ) { //White stars
-        ColorMap.insert( "O", QColor::fromRgb( 255, 255, 255 ) );
-        ColorMap.insert( "B", QColor::fromRgb( 255, 255, 255 ) );
-        ColorMap.insert( "A", QColor::fromRgb( 255, 255, 255 ) );
-        ColorMap.insert( "F", QColor::fromRgb( 255, 255, 255 ) );
-        ColorMap.insert( "G", QColor::fromRgb( 255, 255, 255 ) );
-        ColorMap.insert( "K", QColor::fromRgb( 255, 255, 255 ) );
-        ColorMap.insert( "M", QColor::fromRgb( 255, 255, 255 ) );
-    }
-
-    foreach ( const QString &color, ColorMap.keys() ) {
-        QString imKey = color+"15";
-        QPixmap BigImage( static_cast<int>(15*scale), static_cast<int>(15*scale) ); 
-        BigImage.fill( Qt::transparent );
-
-        QPainter p;
-        p.begin( &BigImage );
-
-        if ( Options::starColorMode() == 0 ) {
-            qreal h, s, v, a;
-            p.setRenderHint( QPainter::Antialiasing, false );
-            QColor starColor = ColorMap[color];
-            starColor.getHsvF(&h, &s, &v, &a);
-            for (int i = 0; i < 8; i++ ) {
-                for (int j = 0; j < 8; j++ ) {
-                    qreal dist = sqrt( pow( i-7., 2. ) + pow( j-7., 2. ) )/7.;
-                    starColor.setHsvF(h, qMin( qreal(1), dist < (10-starColorIntensity)/10.?0:dist ), v, qMax( qreal(0), dist < (10-starColorIntensity)/20.?1:1-dist ) );
-                    p.setPen( starColor );
-                    p.drawPoint( i, j );
-                    p.drawPoint( 14-i, j );
-                    p.drawPoint( i, 14-j );
-                    p.drawPoint (14-i, 14-j);
-                }
-            }
-        } else {
-            p.setRenderHint(QPainter::Antialiasing, true );
-            p.setPen( QPen(ColorMap[color], 2.0*scale ) );
-            p.setBrush( p.pen().color() );
-            p.drawEllipse( QRectF( 2*scale, 2*scale, 10*scale, 10*scale ) );
-        }
-        p.end();
-        StarImage.insert( imKey, BigImage );
-
-        for ( int size = 14; size > 0; size-- ) {
-            imKey = color+QString("%1").arg(size);
-            StarImage.insert( imKey, BigImage.scaled( size*scale, size*scale, Qt::KeepAspectRatio, Qt::SmoothTransformation ) );
-        }
-    }
-}
-
-void StarObject::showPopupMenu( KSPopupMenu *pmenu, const QPoint &pos ) {
-    pmenu->createStarMenu( this ); pmenu->popup( pos );
+void StarObject::initPopupMenu( KSPopupMenu *pmenu ) {
+    pmenu->createStarMenu( this );
 }
 
 void StarObject::updateCoords( KSNumbers *num, bool , const dms*, const dms* ) {
@@ -333,14 +245,14 @@ void StarObject::updateCoords( KSNumbers *num, bool , const dms*, const dms* ) {
     // Correction:  The method below computes the proper motion before the
     // precession.  If we precessed first then the direction of the proper
     // motion correction would depend on how far we've precessed.  -jbb
-    double saveRA = ra0()->Hours();
-    double saveDec = dec0()->Degrees();
+    double saveRA = ra0().Hours();
+    double saveDec = dec0().Degrees();
 
     double newRA, newDec;
 
     // Old, Incorrect Proper motion Computation:
-    //    setRA0( ra0()->Hours() + pmRA()*num->julianMillenia() / (15. * cos( dec0()->radians() ) * 3600.) );
-    //    setDec0( dec0()->Degrees() + pmDec()*num->julianMillenia() / 3600. );
+    //    setRA0( ra0().Hours() + pmRA()*num->julianMillenia() / (15. * cos( dec0().radians() ) * 3600.) );
+    //    setDec0( dec0().Degrees() + pmDec()*num->julianMillenia() / 3600. );
 
     getIndexCoords( num, &newRA, &newDec );
     newRA /= 15.0;                           // getIndexCoords returns in Degrees, while we want the RA in Hours
@@ -356,7 +268,7 @@ void StarObject::getIndexCoords( KSNumbers *num, double *ra, double *dec )
 {
 
     // Old, Incorrect Proper motion Computation:
-    //    double dra = pmRA() * num->julianMillenia() / ( cos( dec0()->radians() ) * 3600.0 );
+    //    double dra = pmRA() * num->julianMillenia() / ( cos( dec0().radians() ) * 3600.0 );
     //    double ddec = pmDec() * num->julianMillenia() / 3600.0;
 
     // Proper Motion Correction should be implemented as motion along a great 
@@ -364,33 +276,34 @@ void StarObject::getIndexCoords( KSNumbers *num, double *ra, double *dec )
     // atan2( pmRA(), pmDec() ) to an angular distance given by the Magnitude of 
     // PM times the number of Julian millenia since J2000.0
 
-    double pm = sqrt( pmRA() * pmRA() + pmDec() * pmDec() ) * num->julianMillenia();   // Proper Motion in arcseconds
+    double pm = pmMagnitude() * num->julianMillenia();   // Proper Motion in arcseconds
     double dir0 = ( pm > 0 ) ? atan2( pmRA(), pmDec() ) : atan2( -pmRA(), -pmDec() );  // Bearing, in radian
 
     ( pm < 0 ) && ( pm = -pm );
 
     double dst = pm * M_PI / ( 180.0 * 3600.0 );
-    //    double phi = M_PI / 2.0 - dec0()->radians();
+    //    double phi = M_PI / 2.0 - dec0().radians();
 
     dms lat1, dtheta;
-    lat1.setRadians( asin( dec0()->sin() * cos( dst ) +
-                           dec0()->cos() * sin( dst ) * cos( dir0 ) ) );
-    dtheta.setRadians( atan2( sin( dir0 ) * sin( dst ) * dec0()->cos(),
-                              cos( dst ) - dec0()->sin() * lat1.sin() ) );
+    lat1.setRadians( asin( dec0().sin() * cos( dst ) +
+                           dec0().cos() * sin( dst ) * cos( dir0 ) ) );
+    dtheta.setRadians( atan2( sin( dir0 ) * sin( dst ) * dec0().cos(),
+                              cos( dst ) - dec0().sin() * lat1.sin() ) );
 
     // Using dms instead, to ensure that the numbers are in the right range.
-    dms finalRA( ra0()->Degrees() + dtheta.Degrees() );
+    dms finalRA( ra0().Degrees() + dtheta.Degrees() );
 
     *ra = finalRA.Degrees();
     *dec = lat1.Degrees();
 
-    //    *ra = ra0()->Degrees() + dra;
-    //    *dec = dec0()->Degrees() + ddec;
+    //    *ra = ra0().Degrees() + dra;
+    //    *dec = dec0().Degrees() + ddec;
 }
 
 double StarObject::pmMagnitude()
 {
-    return sqrt( pmRA() * pmRA() + pmDec() * pmDec() );
+    double cosDec = dec().cos();
+    return sqrt( cosDec * cosDec * pmRA() * pmRA() + pmDec() * pmDec() );
 }
 
 void StarObject::JITupdate( KStarsData* data )
@@ -404,7 +317,12 @@ void StarObject::JITupdate( KStarsData* data )
 }
 
 QString StarObject::sptype( void ) const {
-    return (QString)QByteArray(SpType, 2);
+    return QString( QByteArray(SpType, 2) );
+}
+
+char StarObject::spchar() const
+{
+    return SpType[0];
 }
 
 QString StarObject::gname( bool useGreekChars ) const {
@@ -452,7 +370,7 @@ QString StarObject::greekLetter( bool gchar ) const {
     return letter;
 }
 
-QString StarObject::constell( void ) const {
+QString StarObject::constell() const {
     QString code = name2().mid(4,3);
     if ( code == "And" ) return QString("Andromedae");
     if ( code == "Ant" ) return QString("Antliae");
@@ -546,116 +464,6 @@ QString StarObject::constell( void ) const {
     return QString();
 }
 
-QColor StarObject::color() const {
-    return ColorMap[QString(QChar(SpType[0]))];
-}
-
-void StarObject::updateColors( bool desaturateColors, int saturation ) {
-    //First set colors to their fully-saturated values
-    ColorMap.insert( "O", QColor::fromRgb(   0,   0, 255 ) );
-    ColorMap.insert( "B", QColor::fromRgb(   0, 200, 255 ) );
-    ColorMap.insert( "A", QColor::fromRgb(   0, 255, 255 ) );
-    ColorMap.insert( "F", QColor::fromRgb( 200, 255, 100 ) );
-    ColorMap.insert( "G", QColor::fromRgb( 255, 255,   0 ) );
-    ColorMap.insert( "K", QColor::fromRgb( 255, 100,   0 ) );
-    ColorMap.insert( "M", QColor::fromRgb( 255,   0,   0 ) );
-
-    if ( ! desaturateColors ) return;
-
-    //Desaturate the star colors by mixing in white
-    float sat = 0.1*saturation; //sat is between 0.0 and 1.0
-    int r, g, b;
-    QMapIterator<QString, QColor> it(ColorMap);
-    while ( it.hasNext() ) {
-        it.next();
-        r = int( 255.0*(1.0 - sat) + it.value().red()*sat   );
-        g = int( 255.0*(1.0 - sat) + it.value().green()*sat );
-        b = int( 255.0*(1.0 - sat) + it.value().blue()*sat  );
-
-        ColorMap[ it.key() ] = QColor::fromRgb( r, g, b );
-    }
-}
-
-bool StarObject::isSpecType( char c ) {
-    if( c == 'W' || c == 'O' || c == 'B' || c == 'A' || c == 'F' || c == 'G' || c == 'K' || c == 'M' || c == 'R' || c == 'N' || c == 'S' )
-        return true;
-    else
-        return false;
-}
-
-void StarObject::draw( QPainter &psky, float x, float y, float size,
-                       bool useRealColors, int scIntensity, bool /*showMultiple*/ ) {
-
-    int isize = int(size);
-    if ( isize >= 14 ) {
-        isize = 14;
-    }
-    QString imKey = ( isSpecType( SpType[0] )  ? SpType[0] : ( isSpecType( SpType[1] ) ? SpType[1] : 'A' ) ) + QString("%1").arg(isize);
-    float offset = 0.5*StarImage[imKey].width();
-    psky.drawPixmap( QPointF(x-offset, y-offset), StarImage[imKey] );
-
-    // DEBUG Edit. To check Proper Motion Corrections. Uncomment all related blocks for testing.
-    /*
-    if( !testStar )
-        return;
-
-    dms *ra, *dec;
-    ra = new dms;
-    dec = new dms;
-    KStarsData *data = KStarsData::Instance();
-    SkyMesh *m_skyMesh = SkyMesh::Instance();
-
-    for( int i = 0; i < Trail.size(); i++ ) {
-        //        kDebug() << "Point" << i << "in trixel" << m_skyMesh->indexToName( m_skyMesh->index( Trail.at( i ) ) );
-        Trail.at( i )->updateCoords( data->updateNum(),  true, ra, dec );
-        Trail.at( i )->EquatorialToHorizontal( data->lst(), data->geo()->lat() );
-    }
-
-
-    SkyMap *map = SkyMap::Instance();
-    SkyPoint *pThis, *pLast;
-    QPointF oThis, oMid, oLast;
-    QPointF center;
-    bool isVisible, isVisibleLast;
-
-    psky.setPen( QPen( QBrush( QColor( "white" ) ), 1, Qt::SolidLine ) );
-
-    pLast = Trail.first();
-    oLast = map->toScreen( pLast, true, &isVisibleLast );
-    center = map->toScreen( map->focus() );
-    //    kDebug() << "Entering draw routine to draw PM arc.";
-    for ( int i = 1; i < Trail.size(); i++ ) {
-        pThis = Trail.at( i );
-        oThis = map->toScreen( pThis, true, &isVisible );
-        if ( map->onScreen( oThis, oLast) ) {
-            //            kDebug() << "We have a segment on map!";                
-            if ( isVisible && isVisibleLast ) {
-                //                kDebug() << "Drawing line from (" << oLast.x() - center.x() << "," << oLast.y() - center.y() << ") to (" 
-                //                         << oThis.x() - center.x() << "," << oThis.y() - center.y() << ")" << endl;
-                //                kDebug() << "Or " << pThis->ra()->toHMSString() << "," << pThis->dec()->toDMSString() << "to"
-                //                         << pLast->ra()->toHMSString() << "," << pLast->dec()->toDMSString();
-                psky.drawLine( oLast, oThis );
-            }
-            else if ( isVisibleLast ) {
-                oMid = map->clipLineI( pLast, pThis );
-                psky.drawLine( oLast, oMid );
-            }
-            else if ( isVisible ) {
-                oMid = map->clipLineI( pThis, pLast );
-                psky.drawLine( oMid, oThis );
-            }
-        }
-            
-        pLast = pThis;
-        oLast = oThis;
-        isVisibleLast = isVisible;
-    }
-    */
-    // END DEBUG.
-              
-              
-}
-
 // The two routines below seem overly complicated but at least they are doing
 // the right thing now.  Please resist the temptation to simplify them unless
 // you are prepared to ensure there is no ugly label overlap for all 8 cases
@@ -709,6 +517,22 @@ QString StarObject::labelString() const {
 }
 
 double StarObject::labelOffset() const {
-    return SkyMap::Instance()->scale() * 
-        (6. + 0.5*( 5.0 - mag() ) + 0.01*( Options::zoomFactor()/500. ) );
+    return (6. + 0.5*( 5.0 - mag() ) + 0.01*( Options::zoomFactor()/500. ) );
+}
+
+SkyObject::UID StarObject::getUID() const
+{
+    // mag takes 10 bit
+    SkyObject::UID m = mag()*10; 
+    if( m < 0 ) m = 0;
+
+    // Both RA & dec fits in 24-bits
+    SkyObject::UID ra  = ra0().Degrees() * 36000;
+    SkyObject::UID dec = (ra0().Degrees()+91) * 36000;
+
+    Q_ASSERT("Magnitude is expected to fit into 10bits" && m>=0 && m<(1<<10));
+    Q_ASSERT("RA should fit into 24bits"  && ra>=0  && ra <(1<<24));
+    Q_ASSERT("Dec should fit into 24bits" && dec>=0 && dec<(1<<24));
+
+    return (SkyObject::UID_STAR << 60) | (m << 48) | (ra << 24) | dec;
 }
