@@ -1,5 +1,5 @@
 //
-// This file is part of the Marble Desktop Globe.
+// This file is part of the Marble Virtual Globe.
 //
 // This program is free software licensed under the GNU LGPL. You can
 // find a copy of this license in LICENSE.txt in the top directory of
@@ -15,7 +15,7 @@
  
 
 #include <QtGui/QMainWindow>
-
+#include <QtCore/QDateTime>
 #include "ControlView.h"
 
 
@@ -29,8 +29,10 @@ namespace Marble
 
 class MarbleWidget;
 class SunControlWidget;
+class TimeControlWidget;
 class QtMarbleConfigDialog;
 class DownloadRegionDialog;
+class RoutingWidget;
 
 class MainWindow : public QMainWindow
 {
@@ -58,6 +60,7 @@ class MainWindow : public QMainWindow
  private Q_SLOTS:
     void  showPosition( const QString& position);
     void  showDistance( const QString& position);
+    void  showDateTime();
 
     void  initObject();
     void  editSettings();
@@ -69,15 +72,13 @@ class MainWindow : public QMainWindow
     void  exportMapScreenShot();
     void  showDownloadRegionDialog();
     void  printMapScreenShot();
-    void  printPixmap( QPrinter * printer, const QPixmap& pixmap );
-    void  printPreview();
-    void  paintPrintPreview( QPrinter * printer );
     void  workOffline( bool );
     
     // Edit Menu
     void  copyMap();
     void  copyCoordinates();
-    
+    void  updateMapEditButtonVisibility( const QString &mapTheme );
+
     // View Menu
     void  lockPosition( bool );
     void  createInfoBoxesMenu();
@@ -86,6 +87,7 @@ class MainWindow : public QMainWindow
     void  showClouds( bool );
     void  showAtmosphere( bool );
     void  controlSun();
+    void  controlTime();
     void  showSun( bool );
     void  reload();
     
@@ -100,16 +102,31 @@ class MainWindow : public QMainWindow
     void  aboutMarble();
     void  handbook();
 
+    //Bookmark Menu
+    void  openBookmarkInfoDialog();
+    void  createBookmarksListMenu(QMenu *m_bookmarksListMenu, const GeoDataFolder &folder);
+    void  lookAtBookmark( QAction * action );
+    void  removeAllBookmarks();
+    void  openNewBookmarkFolderDialog();
+    void  createBookmarkMenu();
+    void  createFolderList();
+
     // Download region dialog
     void  connectDownloadRegionDialog();
     void  disconnectDownloadRegionDialog();
     void  downloadRegion();
-    
-    void  setMapTitle();
+
+    // Small screen devices specific slots
+    void showMapViewDialog();
+    void showLegendTab( bool enabled );
+    void showRoutingDialog();
 
  private:
+    void setupZoomButtons();
+
     ControlView *m_controlView;
     SunControlWidget* m_sunControlDialog;
+    TimeControlWidget* m_timeControlDialog;
     QtMarbleConfigDialog *m_configDialog;
     DownloadRegionDialog* m_downloadRegionDialog;
 
@@ -123,8 +140,9 @@ class MainWindow : public QMainWindow
     QMenu *m_settingsMenu;
     QMenu *m_infoBoxesMenu;
     QMenu *m_onlineServicesMenu;
-
+	QMenu *m_bookmarkMenu;
     // File Menu
+    QAction *m_openAct;
     QAction *m_exportMapAct;
     QAction *m_downloadAct;
     QAction *m_downloadRegionAction;
@@ -136,11 +154,13 @@ class MainWindow : public QMainWindow
     // Edit Menu
     QAction *m_copyMapAct;
     QAction *m_copyCoordinatesAct;
+    QAction *m_osmEditAction;
 
     // View Menu
     QAction *m_showCloudsAct;
     QAction *m_showAtmosphereAct;
     QAction *m_controlSunAct;
+    QAction *m_controlTimeAct;
     QAction *m_reloadAct;
 
     // Settings Menu
@@ -153,16 +173,32 @@ class MainWindow : public QMainWindow
     QAction *m_whatsThisAct;
     QAction *m_aboutMarbleAct;
     QAction *m_aboutQtAct;
-    QAction *m_openAct;
     QAction *m_lockFloatItemsAct;
     QAction *m_handbookAct;
 
     // Status Bar
     QString     m_position;
     QString     m_distance;
+    QString     m_clock;
     QLabel      *m_positionLabel;
     QLabel      *m_distanceLabel;    
+    QLabel      *m_clockLabel;
     void updateStatusBar();
+
+	//Bookmark Menu
+    QAction *m_addBookmarkAct;
+    QAction *m_removeAllBookmarksAct;
+    QAction *m_addBookmarkFolderAct;
+
+    // Small screen devices
+    QAction *m_showMapViewDialogAction;
+    QAction *m_toggleLegendTabAction;
+    QAction *m_toggleRoutingTabAction;
+
+    QDialog *m_mapViewDialog;
+    QDialog *m_routingDialog;
+
+    RoutingWidget *m_routingWidget;
 };
 
 } // namespace Marble
