@@ -1,5 +1,5 @@
 //
-// This file is part of the Marble Desktop Globe.
+// This file is part of the Marble Virtual Globe.
 //
 // This program is free software licensed under the GNU LGPL. You can
 // find a copy of this license in LICENSE.txt in the top directory of
@@ -82,7 +82,7 @@ void AbstractDataPluginItem::setAddedAngularResolution( qreal resolution )
     d->m_addedAngularResolution = resolution;
 }
 
-void AbstractDataPluginItem::setSettings( QHash<QString, QVariant> settings )
+void AbstractDataPluginItem::setSettings( const QHash<QString, QVariant>& settings )
 {
     d->m_settings = settings;
 }
