@@ -1,5 +1,5 @@
 //
-// This file is part of the Marble Desktop Globe.
+// This file is part of the Marble Virtual Globe.
 //
 // This program is free software licensed under the GNU LGPL. You can
 // find a copy of this license in LICENSE.txt in the top directory of
@@ -22,101 +22,66 @@
 
 using namespace Marble;
 
-AbstractScanlineTextureMapper::AbstractScanlineTextureMapper( GeoSceneTexture *textureLayer,
-                                                              StackedTileLoader *tileLoader,
-                                                              QObject *parent )
+AbstractScanlineTextureMapper::AbstractScanlineTextureMapper( StackedTileLoader * const tileLoader,
+                                                              QObject * const parent )
     : QObject( parent ),
       m_maxGlobalX( 0 ),
       m_maxGlobalY( 0 ),
-      m_imageHeight( 0 ),
-      m_imageWidth( 0 ),
       m_prevLat( 0.0 ),
       m_prevLon( 0.0 ),
-      m_toTileCoordinatesLon( 0.0 ),
-      m_toTileCoordinatesLat( 0.0 ),
       m_interlaced( false ),
       m_tileLoader( tileLoader ),
       m_tilePosX( 0 ),
       m_tilePosY( 0 ),
-      m_textureLayer( textureLayer ),
+      m_textureProjection( tileLoader->tileProjection() ),  // cache texture projection
+      m_tileSize( tileLoader->tileSize() ),  // cache tile size
       m_tile( 0 ),
       m_previousRadius( 0 ),
-      m_n( 0 ),
-      m_nInverse( 0.0 ),
-      m_nBest( 0 ),
+      m_toTileCoordinatesLon( 0.0 ),
+      m_toTileCoordinatesLat( 0.0 ),
       m_tileLevel( 0 ),
-      m_maxTileLevel( 0 ),
       m_globalWidth( 0 ),
       m_globalHeight( 0 ),
       m_normGlobalWidth( 0.0 ),
-      m_normGlobalHeight( 0.0 ),
-      m_mapThemeIdHash( textureLayer ? qHash( textureLayer->sourceDir() ) : 0 )
+      m_normGlobalHeight( 0.0 )
 {
-    m_tileProjection = textureLayer ? textureLayer->projection()
-        : GeoSceneTexture::Equirectangular;
-
-    connect( m_tileLoader, SIGNAL( tileUpdateAvailable() ), 
-             this,         SLOT( notifyMapChanged() ) );
-
-    detectMaxTileLevel();
-    initTileSize();
 }
 
 
 AbstractScanlineTextureMapper::~AbstractScanlineTextureMapper()
 {
-      m_tileLoader->disconnect();
 }
 
 
-void AbstractScanlineTextureMapper::setLayer( GeoSceneLayer * layer )
+void AbstractScanlineTextureMapper::setRadius( int radius )
 {
-    m_textureLayer = static_cast<GeoSceneTexture *>( layer->groundDataset() );
-    m_tileProjection = m_textureLayer->projection();
-    m_mapThemeIdHash = qHash( m_textureLayer->sourceDir() );
-    m_tileLevel = -1;
-    detectMaxTileLevel();
-    initTileSize();
-}
-
-
-void AbstractScanlineTextureMapper::selectTileLevel( ViewParams* viewParams )
-{
-    const int radius = viewParams->radius();
-
     // As our tile resolution doubles with each level we calculate
     // the tile level from tilesize and the globe radius via log(2)
 
-    qreal  linearLevel = ( 2.0 * (qreal)( radius )
-			    / (qreal) ( m_tileSize.width() ) );
+    qreal  linearLevel = ( 4.0 * (qreal)( radius )
+                               / (qreal)( m_tileSize.width() ) );
     int     tileLevel   = 0;
 
     if ( linearLevel < 1.0 )
         linearLevel = 1.0; // Dirty fix for invalid entry linearLevel
 
-    qreal tileLevelF = log( linearLevel ) / log( 2.0 ) + 1.0;
+    qreal tileLevelF = log( linearLevel ) / log( 2.0 );
     tileLevel = (int)( tileLevelF );
 
 //    mDebug() << "tileLevelF: " << tileLevelF << " tileLevel: " << tileLevel;
 
-    if ( tileLevel > m_maxTileLevel )
-        tileLevel = m_maxTileLevel;
+    if ( tileLevel > m_tileLoader->maximumTileLevel() )
+        tileLevel = m_tileLoader->maximumTileLevel();
 
-    if ( tileLevel != m_tileLevel ) {
-        m_tileLoader->flush();
-        tileLevelInit( tileLevel );
-    }
-}
+    const bool changedTileLevel = tileLevel != m_tileLevel;
 
-
-void AbstractScanlineTextureMapper::tileLevelInit( int tileLevel )
-{
     //    mDebug() << "Texture Level was set to: " << tileLevel;
     m_tileLevel = tileLevel;
 
-    initGlobalWidth();
+    m_globalWidth = m_tileSize.width() * m_tileLoader->tileColumnCount( m_tileLevel );
     m_normGlobalWidth = (qreal)( m_globalWidth / ( 2 * M_PI ) );
-    initGlobalHeight();
+
+    m_globalHeight = m_tileSize.height() * m_tileLoader->tileRowCount( m_tileLevel );
     m_normGlobalHeight = (qreal)( m_globalHeight /  M_PI );
 
     m_maxGlobalX = m_globalWidth  - 1;
@@ -126,35 +91,19 @@ void AbstractScanlineTextureMapper::tileLevelInit( int tileLevel )
     // the center to the upper left corner and subtract the tile position 
     // in that coordinate system. In total this equals a coordinate 
     // transformation to tile coordinates.
-    m_toTileCoordinatesLon = (qreal)(m_globalWidth / 2 - m_tilePosX);
-    m_toTileCoordinatesLat = (qreal)(m_globalHeight / 2 - m_tilePosY);
+    m_toTileCoordinatesLon = (qreal)(0.5 * m_globalWidth - m_tilePosX);
+    m_toTileCoordinatesLat = (qreal)(0.5 * m_globalHeight - m_tilePosY);
 
-    emit tileLevelChanged( m_tileLevel );
-}
+    if ( changedTileLevel ) {
+        m_tileLoader->flush();
 
-
-void AbstractScanlineTextureMapper::resizeMap(int width, int height)
-{
-    m_imageHeight = height;
-    m_imageWidth  = width;
-
-    // Find the optimal interpolation interval m_nBest for the 
-    // current image canvas width
-    m_nBest = 2;
-
-    int  nEvalMin = m_imageWidth - 1;
-    for ( int it = 1; it < 48; ++it ) {
-        int nEval = ( m_imageWidth - 1 ) / it + ( m_imageWidth - 1 ) % it;
-        if ( nEval < nEvalMin ) {
-            nEvalMin = nEval;
-            m_nBest = it; 
-        }
+        emit tileLevelChanged( m_tileLevel );
     }
 }
 
-void AbstractScanlineTextureMapper::pixelValueF(qreal lon,
-                                               qreal lat, 
-                                               QRgb* scanLine )
+
+void AbstractScanlineTextureMapper::pixelValueF( const qreal lon, const qreal lat,
+                                                 QRgb* const scanLine )
 {
     // The same method using integers performs about 33% faster.
     // However we need the qreal version to create the high quality mode.
@@ -170,7 +119,7 @@ void AbstractScanlineTextureMapper::pixelValueF(qreal lon,
     // same tile. However at the tile border we might "fall off". If that 
     // happens we need to find out the next tile that needs to be loaded.
 
-    if ( posX  >= (qreal)( m_tileSize.width() ) 
+    if ( posX  >= (qreal)( m_tileSize.width() )
          || posX < 0.0
          || posY >= (qreal)( m_tileSize.height() )
          || posY < 0.0 )
@@ -185,9 +134,8 @@ void AbstractScanlineTextureMapper::pixelValueF(qreal lon,
     }
 }
 
-void AbstractScanlineTextureMapper::pixelValue(qreal lon,
-                                               qreal lat, 
-                                               QRgb* scanLine )
+void AbstractScanlineTextureMapper::pixelValue( const qreal lon, const qreal lat,
+                                                QRgb* const scanLine )
 {
     // The same method using integers performs about 33% faster.
     // However we need the qreal version to create the high quality mode.
@@ -229,9 +177,8 @@ void AbstractScanlineTextureMapper::pixelValue(qreal lon,
 // This method will do by far most of the calculations for the 
 // texturemapping, so we move towards integer math to improve speed.
 
-void AbstractScanlineTextureMapper::pixelValueApproxF(const qreal& lon,
-                              const qreal& lat, QRgb *scanLine,
-                              int n )
+void AbstractScanlineTextureMapper::pixelValueApproxF( const qreal lon, const qreal lat,
+                                                       QRgb *scanLine, const int n )
 {
     // stepLon/Lat: Distance between two subsequent approximated positions
 
@@ -356,14 +303,14 @@ void AbstractScanlineTextureMapper::pixelValueApproxF(const qreal& lon,
 }
 
 
-bool AbstractScanlineTextureMapper::isOutOfTileRangeF( qreal itLon, qreal itLat,
-                                                       qreal itStepLon, qreal itStepLat,
-                                                       int n ) const
+bool AbstractScanlineTextureMapper::isOutOfTileRangeF( const qreal itLon, const qreal itLat,
+                                                       const qreal itStepLon, const qreal itStepLat,
+                                                       const int n ) const
 {
-    qreal minIPosX = itLon + itStepLon;
-    qreal minIPosY = itLat + itStepLat;
-    qreal maxIPosX = itLon + itStepLon * ( n - 1 );
-    qreal maxIPosY = itLat + itStepLat * ( n - 1 );
+    const qreal minIPosX = itLon + itStepLon;
+    const qreal minIPosY = itLat + itStepLat;
+    const qreal maxIPosX = itLon + itStepLon * ( n - 1 );
+    const qreal maxIPosY = itLat + itStepLat * ( n - 1 );
     return (    maxIPosX >= m_tileSize.width()  || maxIPosX < 0
              || maxIPosY >= m_tileSize.height() || maxIPosY < 0
              || minIPosX >= m_tileSize.width()  || minIPosX < 0
@@ -371,9 +318,8 @@ bool AbstractScanlineTextureMapper::isOutOfTileRangeF( qreal itLon, qreal itLat,
 }
 
 
-void AbstractScanlineTextureMapper::pixelValueApprox(const qreal& lon,
-                              const qreal& lat, QRgb *scanLine,
-                              int n )
+void AbstractScanlineTextureMapper::pixelValueApprox( const qreal lon, const qreal lat,
+                                                      QRgb *scanLine, const int n )
 {
     // stepLon/Lat: Distance between two subsequent approximated positions
 
@@ -480,14 +426,14 @@ void AbstractScanlineTextureMapper::pixelValueApprox(const qreal& lon,
 }
 
 
-bool AbstractScanlineTextureMapper::isOutOfTileRange( int itLon, int itLat,
-                                                      int itStepLon, int itStepLat,
-                                                      int n ) const
+bool AbstractScanlineTextureMapper::isOutOfTileRange( const int itLon, const int itLat,
+                                                      const int itStepLon, const int itStepLat,
+                                                      const int n ) const
 {
-    int minIPosX = ( itLon + itStepLon ) >> 7;
-    int minIPosY = ( itLat + itStepLat ) >> 7;
-    int maxIPosX = ( itLon + itStepLon * ( n - 1 ) ) >> 7;
-    int maxIPosY = ( itLat + itStepLat * ( n - 1 ) ) >> 7;
+    const int minIPosX = ( itLon + itStepLon ) >> 7;
+    const int minIPosY = ( itLat + itStepLat ) >> 7;
+    const int maxIPosX = ( itLon + itStepLon * ( n - 1 ) ) >> 7;
+    const int maxIPosY = ( itLat + itStepLat * ( n - 1 ) ) >> 7;
     return (    maxIPosX >= m_tileSize.width()  || maxIPosX < 0
              || maxIPosY >= m_tileSize.height() || maxIPosY < 0
              || minIPosX >= m_tileSize.width()  || minIPosX < 0
@@ -495,7 +441,7 @@ bool AbstractScanlineTextureMapper::isOutOfTileRange( int itLon, int itLat,
 }
 
 
-int AbstractScanlineTextureMapper::interpolationStep( ViewParams *viewParams ) const
+int AbstractScanlineTextureMapper::interpolationStep( ViewParams * const viewParams )
 {
     if ( viewParams->mapQuality() == PrintQuality ) {
         return 1;    // Don't interpolate for print quality.
@@ -505,7 +451,21 @@ int AbstractScanlineTextureMapper::interpolationStep( ViewParams *viewParams ) c
         return 8;
     }
 
-    return m_nBest;
+    // Find the optimal interpolation interval m_nBest for the 
+    // current image canvas width
+    const int width = viewParams->canvasImage()->width();
+
+    int nBest = 2;
+    int nEvalMin = width - 1;
+    for ( int it = 1; it < 48; ++it ) {
+        int nEval = ( width - 1 ) / it + ( width - 1 ) % it;
+        if ( nEval < nEvalMin ) {
+            nEvalMin = nEval;
+            nBest = it; 
+        }
+    }
+
+    return nBest;
 }
 
 
@@ -515,12 +475,16 @@ void AbstractScanlineTextureMapper::nextTile( int &posX, int &posY )
     // ( with origin in upper left corner, measured in pixel) 
 
     int lon = posX + m_tilePosX;
-    if ( lon > m_maxGlobalX ) lon -= m_maxGlobalX;
-    if ( lon < 0 ) lon += m_maxGlobalX;
+    if ( lon > m_maxGlobalX )
+        lon -= m_maxGlobalX;
+    else if ( lon < 0 )
+        lon += m_maxGlobalX;
 
     int lat = posY + m_tilePosY;
-    if ( lat > m_maxGlobalY ) lat -= m_maxGlobalY;
-    if ( lat < 0 ) lat += m_maxGlobalY;
+    if ( lat > m_maxGlobalY )
+        lat -= m_maxGlobalY;
+    else if ( lat < 0 )
+        lat += m_maxGlobalY;
 
     // tileCol counts the tile columns left from the current tile.
     // tileRow counts the tile rows on the top from the current tile.
@@ -528,8 +492,7 @@ void AbstractScanlineTextureMapper::nextTile( int &posX, int &posY )
     int tileCol = lon / m_tileSize.width();
     int tileRow = lat / m_tileSize.height();
 
-    m_tile = m_tileLoader->loadTile( TileId( m_mapThemeIdHash, m_tileLevel, tileCol, tileRow ),
-                                     DownloadBrowse );
+    m_tile = m_tileLoader->loadTile( TileId( 0, m_tileLevel, tileCol, tileRow ), DownloadBrowse );
     m_tile->setUsed( true );
 
     // Update position variables:
@@ -538,11 +501,11 @@ void AbstractScanlineTextureMapper::nextTile( int &posX, int &posY )
     // ( origin upper left, measured in pixels )
 
     m_tilePosX = tileCol * m_tileSize.width();
-    m_toTileCoordinatesLon = (qreal)(m_globalWidth / 2 - m_tilePosX);
+    m_toTileCoordinatesLon = (qreal)(0.5 * m_globalWidth - m_tilePosX);
     posX = lon - m_tilePosX;
 
     m_tilePosY = tileRow * m_tileSize.height();
-    m_toTileCoordinatesLat = (qreal)(m_globalHeight / 2 - m_tilePosY);
+    m_toTileCoordinatesLat = (qreal)(0.5 * m_globalHeight - m_tilePosY);
     posY = lat - m_tilePosY;
 }
 
@@ -552,12 +515,16 @@ void AbstractScanlineTextureMapper::nextTile( qreal &posX, qreal &posY )
     // ( with origin in upper left corner, measured in pixel) 
 
     int lon = (int)(posX + m_tilePosX);
-    if ( lon > m_maxGlobalX ) lon -= m_maxGlobalX;
-    if ( lon < 0 ) lon += m_maxGlobalX;
+    if ( lon > m_maxGlobalX )
+        lon -= m_maxGlobalX;
+    else if ( lon < 0 )
+        lon += m_maxGlobalX;
 
     int lat = (int)(posY + m_tilePosY);
-    if ( lat > m_maxGlobalY ) lat -= m_maxGlobalY;
-    if ( lat < 0 ) lat += m_maxGlobalY;
+    if ( lat > m_maxGlobalY )
+        lat -= m_maxGlobalY;
+    else if ( lat < 0 )
+        lat += m_maxGlobalY;
 
     // tileCol counts the tile columns left from the current tile.
     // tileRow counts the tile rows on the top from the current tile.
@@ -565,8 +532,7 @@ void AbstractScanlineTextureMapper::nextTile( qreal &posX, qreal &posY )
     int tileCol = lon / m_tileSize.width();
     int tileRow = lat / m_tileSize.height();
 
-    m_tile = m_tileLoader->loadTile( TileId( m_mapThemeIdHash, m_tileLevel, tileCol, tileRow ),
-                                     DownloadBrowse );
+    m_tile = m_tileLoader->loadTile( TileId( 0, m_tileLevel, tileCol, tileRow ), DownloadBrowse );
     m_tile->setUsed( true );
 
     // Update position variables:
@@ -575,51 +541,12 @@ void AbstractScanlineTextureMapper::nextTile( qreal &posX, qreal &posY )
     // ( origin upper left, measured in pixels )
 
     m_tilePosX = tileCol * m_tileSize.width();
-    m_toTileCoordinatesLon = (qreal)(m_globalWidth / 2 - m_tilePosX);
+    m_toTileCoordinatesLon = (qreal)(0.5 * m_globalWidth - m_tilePosX);
     posX = lon - m_tilePosX;
 
     m_tilePosY = tileRow * m_tileSize.height();
-    m_toTileCoordinatesLat = (qreal)(m_globalHeight / 2 - m_tilePosY);
+    m_toTileCoordinatesLat = (qreal)(0.5 * m_globalHeight - m_tilePosY);
     posY = lat - m_tilePosY;
 }
 
-void AbstractScanlineTextureMapper::notifyMapChanged()
-{
-    detectMaxTileLevel();
-    //mDebug() << "AbstractScanlineTextureMapper: emitting mapChanged";
-    emit mapChanged();
-}
-
-void AbstractScanlineTextureMapper::detectMaxTileLevel()
-{
-    m_maxTileLevel = StackedTileLoader::maximumTileLevel( m_textureLayer );
-//    mDebug() << "MaxTileLevel: " << m_maxTileLevel;
-}
-
-void AbstractScanlineTextureMapper::initGlobalWidth()
-{
-    m_globalWidth = m_tileSize.width()
-        * TileLoaderHelper::levelToColumn( m_textureLayer->levelZeroColumns(), m_tileLevel );
-}
-
-void AbstractScanlineTextureMapper::initGlobalHeight()
-{
-    m_globalHeight = m_tileSize.height()
-        * TileLoaderHelper::levelToRow( m_textureLayer->levelZeroRows(), m_tileLevel );
-}
-
-void AbstractScanlineTextureMapper::initTileSize()
-{
-    if ( !m_textureLayer || !m_tileLoader )
-        return;
-
-    Q_ASSERT( m_textureLayer );
-    Q_ASSERT( m_tileLoader );
-    TileId id( m_textureLayer->sourceDir(), 0, 0, 0 );
-    StackedTile * const testTile = m_tileLoader->loadTile( id, DownloadBrowse );
-    Q_ASSERT( testTile );
-    m_tileSize = testTile->resultTile()->size();
-    Q_ASSERT( !m_tileSize.isEmpty() );
-}
-
 #include "AbstractScanlineTextureMapper.moc"
