@@ -1,5 +1,5 @@
 //
-// This file is part of the Marble Desktop Globe.
+// This file is part of the Marble Virtual Globe.
 //
 // This program is free software licensed under the GNU LGPL. You can
 // find a copy of this license in LICENSE.txt in the top directory of
@@ -20,8 +20,7 @@ namespace Marble
 
 AbstractTilePrivate::AbstractTilePrivate( const TileId& id )
     : m_id( id ),
-      m_used( false ),
-      m_state( AbstractTile::TileEmpty )
+      m_used( false )
 {
 }
 
@@ -63,12 +62,6 @@ void AbstractTile::setUsed( bool used )
     d->m_used = used;
 }
 
-AbstractTile::TileState AbstractTile::state() const
-{
-    Q_D( const AbstractTile );
-    return d->m_state;
-}
-
 }
 
 #include "AbstractTile.moc"
