@@ -1,5 +1,5 @@
 //
-// This file is part of the Marble Desktop Globe.
+// This file is part of the Marble Virtual Globe.
 //
 // This program is free software licensed under the GNU LGPL. You can
 // find a copy of this license in LICENSE.txt in the top directory of
@@ -28,7 +28,6 @@ class AbstractTilePrivate
 
     TileId    m_id;
     bool      m_used;
-    AbstractTile::TileState m_state;
 
     AbstractTile * q_ptr;
 };
