@@ -1,5 +1,5 @@
 //
-// This file is part of the Marble Desktop Globe.
+// This file is part of the Marble Virtual Globe.
 //
 // This program is free software licensed under the GNU LGPL. You can
 // find a copy of this license in LICENSE.txt in the top directory of
@@ -11,10 +11,10 @@
 // Copyright 2008      Pino Toscano <pino@kde.org>
 //
 
+#ifndef MARBLE_HTTPJOB_H
+#define MARBLE_HTTPJOB_H
 
-#ifndef HTTPJOB_H
-#define HTTPJOB_H
-
+#include <QtCore/QByteArray>
 #include <QtCore/QObject>
 #include <QtCore/QString>
 #include <QtCore/QUrl>
@@ -49,6 +49,10 @@ class MARBLE_EXPORT HttpJob: public QObject
     DownloadUsage downloadUsage() const;
     void setDownloadUsage( const DownloadUsage );
 
+    void setUserAgentPluginId( const QString & pluginId ) const;
+
+    QByteArray userAgent() const;
+
  Q_SIGNALS:
     /**
      * errorCode contains 0, if there was no error and 1 otherwise
@@ -73,4 +77,4 @@ class MARBLE_EXPORT HttpJob: public QObject
 
 }
 
-#endif // HTTPJOB_H
+#endif
