@@ -1,5 +1,5 @@
 //
-// This file is part of the Marble Desktop Globe.
+// This file is part of the Marble Virtual Globe.
 //
 // This program is free software licensed under the GNU LGPL. You can
 // find a copy of this license in LICENSE.txt in the top directory of
@@ -18,21 +18,23 @@
 #include <QtCore/QAbstractItemModel>
 
 #include "global.h"
-#include "ExtDateTime.h"
+#include "MarbleClock.h"
 #include "MarbleDebug.h"
 #include "MarbleModel.h"
-#include "MarbleGeoDataModel.h"
-#include "MarbleGeometryModel.h"
 #include "MarblePlacemarkModel.h"
 #include "Planet.h"
 
 #include "FileViewModel.h"
 #include "PluginManager.h"
+#include "GeoDataTreeModel.h"
 #include "GeoDataParser.h"
+#include "PositionTracking.h"
 
 #include "GeoSceneDocument.h"
 #include "GeoSceneHead.h"
 
+#include "routing/RoutingManager.h"
+
 namespace Marble
 {
 
@@ -42,25 +44,22 @@ class MarbleDataFacadePrivate
     MarbleDataFacadePrivate( MarbleModel *model )
         : m_model( model ),
         m_fileviewmodel( new FileViewModel() ),
-        m_geodatamodel( new MarbleGeoDataModel() ),
-        m_geometrymodel( new MarbleGeometryModel() ),
-        m_placemarkmodel( new MarblePlacemarkModel )
+        m_placemarkmodel( new MarblePlacemarkModel ),
+        m_treemodel( new GeoDataTreeModel)
     {
     }
 
     ~MarbleDataFacadePrivate()
     {
         delete m_fileviewmodel;
-        delete m_geodatamodel;
-        delete m_geometrymodel;
         delete m_placemarkmodel;
+        delete m_treemodel;
     }
 
     MarbleModel  *m_model;
     FileViewModel *m_fileviewmodel;
-    MarbleGeoDataModel *m_geodatamodel;
-    MarbleGeometryModel *m_geometrymodel;
     MarblePlacemarkModel *m_placemarkmodel;
+    GeoDataTreeModel *m_treemodel;
 };
 
 
@@ -86,7 +85,7 @@ const Planet* MarbleDataFacade::planet() const
 
 QDateTime MarbleDataFacade::dateTime() const
 {
-    return d->m_model->dateTime()->datetime();
+    return d->m_model->clock()->dateTime();
 }
 
 QString MarbleDataFacade::target() const
@@ -100,14 +99,9 @@ QString MarbleDataFacade::target() const
     return QString();
 }
 
-MarbleGeoDataModel* MarbleDataFacade::geoDataModel()
+PositionTracking* MarbleDataFacade::positionTracking() const
 {
-    return d->m_geodatamodel;
-}
-
-MarbleGeometryModel* MarbleDataFacade::geometryModel()
-{
-    return d->m_geometrymodel;
+    return d->m_model->positionTracking();
 }
 
 MarblePlacemarkModel* MarbleDataFacade::placemarkModel()
@@ -125,5 +119,15 @@ PluginManager* MarbleDataFacade::pluginManager()
     return d->m_model->pluginManager();
 }
 
+RoutingManager* MarbleDataFacade::routingManager()
+{
+    return d->m_model->routingManager();
+}
+
+GeoDataTreeModel* MarbleDataFacade::treeModel() const
+{
+    return d->m_treemodel;
+}
+
 }
 
