@@ -1,5 +1,5 @@
 //
-// This file is part of the Marble Desktop Globe.
+// This file is part of the Marble Virtual Globe.
 //
 // This program is free software licensed under the GNU LGPL. You can
 // find a copy of this license in LICENSE.txt in the top directory of
@@ -35,13 +35,23 @@ class StackedTileLoader;
 class SphericalScanlineTextureMapper : public AbstractScanlineTextureMapper
 {
  public:
-    SphericalScanlineTextureMapper( GeoSceneTexture *textureLayer, StackedTileLoader *tileLoader,
-                                    QObject *parent = 0 );
+    SphericalScanlineTextureMapper( StackedTileLoader *tileLoader, QObject *parent = 0 );
 
-    void mapTexture( ViewParams *viewParams );
+    virtual void mapTexture( GeoPainter *painter,
+                             ViewParams *viewParams,
+                             const QRect &dirtyRect,
+                             TextureColorizer *texColorizer );
+
+    virtual void setRepaintNeeded();
+
+ private:
+    void mapTexture( ViewParams *viewParams,
+                     TextureColorizer *texColorizer );
 
- protected:
     inline bool needsFilter( const QRgb& rgb, int& oldR, int& oldB, int &oldG  );
+
+ private:
+    bool m_repaintNeeded;
 };
 
 }
