@@ -1,5 +1,5 @@
 //
-// This file is part of the Marble Desktop Globe.
+// This file is part of the Marble Virtual Globe.
 //
 // This program is free software licensed under the GNU LGPL. You can
 // find a copy of this license in LICENSE.txt in the top directory of
@@ -62,16 +62,13 @@ class StackedTile : public AbstractTile
     friend class StackedTileLoader;
 
  public:
-    explicit StackedTile( TileId const& tid, QObject * parent = 0 );
+    explicit StackedTile( TileId const& tid, QVector<QSharedPointer<TextureTile> > const &tiles );
     virtual ~StackedTile();
 
     int depth() const;
     int numBytes() const;
     bool isExpired() const;
 
-    bool forMergedLayerDecorator() const;
-    void setForMergedLayerDecorator();
-
 /*!
     \brief Returns the stack of TextureTiles
     \return A non-zero pointer to the container of TextureTile objects.
@@ -107,28 +104,12 @@ class StackedTile : public AbstractTile
     // This method passes the top left pixel (if known already) for better performance
     uint pixelF( qreal x, qreal y, const QRgb& pixel ) const; 
 
- protected:
-    StackedTile( StackedTilePrivate &dd, QObject *parent );
-
  private:
     Q_DECLARE_PRIVATE( StackedTile )
     Q_DISABLE_COPY( StackedTile )
 
-    // TODO: move the private methods into the private class. 
-    
-/*!
-    \brief Appends a TextureTile to the stack und updates the completion state.
-*/    
-    void addTile( QSharedPointer<TextureTile> const & );
-    
-/*!
-    \brief Updates the completion state based on the state of each TextureTile.
-*/    
-    void deriveCompletionState();
     void initJumpTables();
     
-    bool hasTiles() const;
-    
 /*!
     \brief This method performs the actual merge process.
 */    
