@@ -1,5 +1,5 @@
 //
-// This file is part of the Marble Desktop Globe.
+// This file is part of the Marble Virtual Globe.
 //
 // This program is free software licensed under the GNU LGPL. You can
 // find a copy of this license in LICENSE.txt in the top directory of
@@ -7,12 +7,12 @@
 //
 // Copyright 2008      David Roberts  <dvdr18@gmail.com>
 // Copyright 2008      Inge Wallin    <inge@lysator.liu.se>
+// Copyright 2010      Harshit Jain   <hjain.itbhu@gmail.com>
 //
 
 #ifndef MARBLE_SUNCONTROLWIDGET_H
 #define MARBLE_SUNCONTROLWIDGET_H
 
-
 #include <QtCore/QDateTime>
 #include <QtCore/QTime>
 #include <QtGui/QDialog>
@@ -33,33 +33,25 @@ class MARBLE_EXPORT SunControlWidget : public QDialog
     Q_OBJECT
 	
  public:
-    SunControlWidget(QWidget* parent, SunLocator* sunLocator);
-    ~SunControlWidget();
+    SunControlWidget( SunLocator* sunLocator, QWidget* parent = 0 );
+    virtual ~SunControlWidget();
+    void setSunShading( bool );
 
  private Q_SLOTS:
-    void showSunClicked(bool checked);
-    void nowClicked(bool checked);
-    void showSunShadingClicked(int index);
-    void centerSunClicked(bool checked);
-    void timeChanged(const QTime& time);
-    void dateChanged();
-    void hourChanged(int hour);
-	
-    void updateDateTime();
-	void speedChanged(int speed);
+    void apply();
 	
  Q_SIGNALS:
-    void showSun(bool show);
-	
- private:
-    void datetimeChanged(QDateTime datetime);
-	
+    void showSun( bool show );
+    void showSunInZenith( bool show );
+
  protected:
-    void showEvent(QShowEvent* event);
     Q_DISABLE_COPY( SunControlWidget )
 
+    void showEvent(QShowEvent* event);
+
     Ui::SunControlWidget *m_uiWidget;
     SunLocator           *m_sunLocator;
+    QString               m_shadow;
 };
 
 }
