@@ -52,14 +52,12 @@ class GEODATA_EXPORT GeoDataFolder : public GeoDataContainer
  public:
     GeoDataFolder();
     GeoDataFolder( const GeoDataFolder& other );
-    GeoDataFolder( const GeoDataFeature& other );
     ~GeoDataFolder();
 
     /// Provides type information for downcasting a GeoData
     virtual QString nodeType() const;
-    virtual bool isFolder() const { return true; }
 
-private:
+ private:
     GeoDataFolderPrivate *p() const;
 };
 
