@@ -1,5 +1,5 @@
 //
-// This file is part of the Marble Desktop Globe.
+// This file is part of the Marble Virtual Globe.
 //
 // This program is free software licensed under the GNU LGPL. You can
 // find a copy of this license in LICENSE.txt in the top directory of
@@ -15,6 +15,7 @@
 
 #include <QtCore/QFlags>
 #include <QtCore/QVector>
+#include <QtCore/QMetaType>
 
 #include "global.h"
 
@@ -66,7 +67,7 @@ class GeoDataLineStringPrivate;
         In this case Latitude circles are followed as soon as two subsequent
         nodes have exactly the same amount of latitude. In all other places the
         line segments follow great circles.
-    
+
     Some convenience methods have been added that allow to calculate the
     geodesic bounding box or the length of a LineString.
 */
@@ -79,19 +80,19 @@ class GEODATA_EXPORT GeoDataLineString : public GeoDataGeometry
     typedef QVector<GeoDataCoordinates>::ConstIterator ConstIterator;
     typedef QVector<GeoDataCoordinates>::const_iterator const_iterator;
 
-    
+
 /*!
     \brief Creates a new LineString.
 */
     explicit GeoDataLineString( TessellationFlags f = NoTessellation );
 
-    
+
 /*!
     \brief Creates a LineString from an existing geometry object.
 */
     GeoDataLineString( const GeoDataGeometry &other );
 
-    
+
 /*!
     \brief Destroys a LineString.
 */
@@ -100,7 +101,7 @@ class GEODATA_EXPORT GeoDataLineString : public GeoDataGeometry
     /// Provides type information for downcasting a GeoNode
     virtual QString nodeType() const;
 
-    
+
 /*!
     \brief Returns whether a LineString is a closed polygon.
 
@@ -108,7 +109,7 @@ class GEODATA_EXPORT GeoDataLineString : public GeoDataGeometry
 */
     virtual bool isClosed() const;
 
-    
+
 /*!
     \brief Returns whether the LineString follows the earth's surface.
 
@@ -117,7 +118,7 @@ class GEODATA_EXPORT GeoDataLineString : public GeoDataGeometry
 */
     bool tessellate() const;
 
-    
+
 /*!
     \brief Sets the tessellation property for the LineString.
 
@@ -128,41 +129,37 @@ class GEODATA_EXPORT GeoDataLineString : public GeoDataGeometry
 */
     void setTessellate( bool tessellate );
 
-    
+
 /*!
     \brief Returns the tessellation flags for a LineString.
 */
     TessellationFlags tessellationFlags() const;
 
-    
+
 /*!
     \brief Sets the given tessellation flags for a LineString.
 */
     void setTessellationFlags( TessellationFlags f );
 
-    
+
 /*!
     \brief Returns the smallest latLonAltBox that contains the LineString.
 
     \see GeoDataLatLonAltBox
 */
-    GeoDataLatLonAltBox latLonAltBox() const;
 
-    
-/*!
-    \brief Returns the length of the LineString across a sphere.
+   virtual GeoDataLatLonAltBox latLonAltBox() const;
 
-    As a parameter the \a planetRadius needs to be passed.
+/**
+  * @brief Returns the length of LineString across a sphere starting from a coordinate in LineString
+  * This method can be used as an approximation for distances along LineStrings.
+  * The unit used for the resulting length matches the unit of the planet
+  * radius.
+  * @param planetRadius radius of the sphere
+  * @param offset position of coordinate within LineString
+  */
+    virtual qreal length( qreal planetRadius, int offset = 0 ) const;
 
-    \return The return value is the length of the LineString.
-    The unit used for the resulting length matches the unit of the planet
-    radius.
-
-    This method can be used as an approximation for distances along LineStrings.
-*/    
-    virtual qreal length( qreal planetRadius ) const;
-
-    
 /*!
     \brief Provides a more generic representation of the LineString.
 
@@ -172,7 +169,7 @@ class GEODATA_EXPORT GeoDataLineString : public GeoDataGeometry
 */
     virtual QVector<GeoDataLineString*> toRangeCorrected() const;
 
-    
+
 /*!
     \brief The line string with nodes that have proper longitude/latitude ranges.
 
@@ -184,7 +181,7 @@ class GEODATA_EXPORT GeoDataLineString : public GeoDataGeometry
 */
     virtual GeoDataLineString toNormalized() const;
 
-    
+
 /*!
     \brief The line string with more generic pole values.
 
@@ -196,7 +193,7 @@ class GEODATA_EXPORT GeoDataLineString : public GeoDataGeometry
 */
     virtual GeoDataLineString toPoleCorrected() const;
 
-    
+
 /*!
     \brief The line string corrected for date line crossing.
 
@@ -208,7 +205,7 @@ class GEODATA_EXPORT GeoDataLineString : public GeoDataGeometry
     virtual QVector<GeoDataLineString*> toDateLineCorrected() const;
 
 
-    
+
     // "Reimplementation" of QVector API
 /*!
     \brief Returns whether the LineString has no nodes at all.
@@ -217,13 +214,13 @@ class GEODATA_EXPORT GeoDataLineString : public GeoDataGeometry
 */
     bool isEmpty() const;
 
-    
+
 /*!
     \brief Returns the number of nodes in a LineString.
 */
     int size() const;
 
-    
+
 /*!
     \brief Returns a reference to the coordinates of a node at a given position.
     This method detaches the returned coordinate object from the line string.
@@ -237,14 +234,14 @@ class GEODATA_EXPORT GeoDataLineString : public GeoDataGeometry
 */
     const GeoDataCoordinates& at( int pos ) const;
 
-    
+
 /*!
     \brief Returns a reference to the coordinates of a node at a given position.
     This method detaches the returned coordinate object from the line string.
 */
     GeoDataCoordinates& operator[]( int pos );
 
-    
+
 /*!
     \brief Returns a reference to the coordinates of a node at a given position.
     This method does not detach the returned coordinate object from the line string.
@@ -258,14 +255,14 @@ class GEODATA_EXPORT GeoDataLineString : public GeoDataGeometry
 */
     GeoDataCoordinates& first();
 
-    
+
 /*!
     \brief Returns a reference to the first node in the LineString.
     This method does not detach the returned coordinate object from the line string.
 */
     const GeoDataCoordinates& first() const;
 
-    
+
 /*!
     \brief Returns a reference to the last node in the LineString.
     This method detaches the returned coordinate object from the line string.
@@ -279,7 +276,7 @@ class GEODATA_EXPORT GeoDataLineString : public GeoDataGeometry
 */
     const GeoDataCoordinates& last() const;
 
-    
+
 /*!
     \brief Appends a given geodesic position as a new node to the LineString.
 */
@@ -291,25 +288,25 @@ class GEODATA_EXPORT GeoDataLineString : public GeoDataGeometry
 */
     GeoDataLineString& operator << ( const GeoDataCoordinates& position );
 
-    
+
 /*!
     \brief Appends a given LineString to the end of the LineString.
 */
     GeoDataLineString& operator << ( const GeoDataLineString& lineString );
 
-    
+
 /*!
     \brief Returns an iterator that points to the begin of the LineString.
 */
     QVector<GeoDataCoordinates>::Iterator begin();
 
-    
+
 /*!
     \brief Returns an iterator that points to the end of the LineString.
 */
     QVector<GeoDataCoordinates>::Iterator end();
 
-    
+
 /*!
     \brief Returns a const iterator that points to the begin of the LineString.
 */
@@ -321,19 +318,19 @@ class GEODATA_EXPORT GeoDataLineString : public GeoDataGeometry
 */
     QVector<GeoDataCoordinates>::ConstIterator constEnd() const;
 
-    
+
 /*!
     \brief Destroys all nodes in a LineString.
 */
     void clear();
 
-    
+
 /*!
     \brief Removes the node at the given position and returns it.
 */
     QVector<GeoDataCoordinates>::Iterator erase ( QVector<GeoDataCoordinates>::Iterator position );
 
-    
+
 /*!
     \brief Removes the nodes within the given range and returns them.
 */
@@ -346,7 +343,7 @@ class GEODATA_EXPORT GeoDataLineString : public GeoDataGeometry
 */
     void remove ( int i );
 
-    
+
     // Serialization
 /*!
     \brief Serialize the LineString to a stream.
@@ -354,14 +351,14 @@ class GEODATA_EXPORT GeoDataLineString : public GeoDataGeometry
 */
     virtual void pack( QDataStream& stream ) const;
 
-    
+
 /*!
     \brief Unserialize the LineString from a stream.
     \param stream the stream.
 */
     virtual void unpack( QDataStream& stream );
 
-    
+
  protected:
     GeoDataLineStringPrivate *p() const;
     GeoDataLineString(GeoDataLineStringPrivate* priv);
@@ -369,4 +366,6 @@ class GEODATA_EXPORT GeoDataLineString : public GeoDataGeometry
 
 }
 
+Q_DECLARE_METATYPE( Marble::GeoDataLineString )
+
 #endif
