@@ -1,5 +1,5 @@
 //
-// This file is part of the Marble Desktop Globe.
+// This file is part of the Marble Virtual Globe.
 //
 // This program is free software licensed under the GNU LGPL. You can
 // find a copy of this license in LICENSE.txt in the top directory of
@@ -42,9 +42,9 @@ bool GeoDataLinearRing::isClosed() const
     return true;
 }
 
-qreal GeoDataLinearRing::length( qreal planetRadius ) const
+qreal GeoDataLinearRing::length( qreal planetRadius, int offset ) const
 {
-    qreal  length = GeoDataLineString::length( planetRadius );
+    qreal  length = GeoDataLineString::length( planetRadius, offset );
 
     return length + planetRadius * distanceSphere( last(), first() );
 }
@@ -73,5 +73,32 @@ QVector<GeoDataLineString*> GeoDataLinearRing::toRangeCorrected() const
     return p()->m_rangeCorrected;
 }
 
+bool GeoDataLinearRing::contains( const GeoDataCoordinates &coordinates ) const
+{
+    // Quick bounding box check
+    if ( !latLonAltBox().contains( coordinates ) ) {
+        return false;
+    }
+
+    int const points = size();
+    bool inside = false; // also true for points = 0
+    int j = points - 1;
+
+    for ( int i=0; i<points; ++i ) {
+        GeoDataCoordinates one = at( i );
+        GeoDataCoordinates two = at( j );
+
+        if ( ( one.longitude() < coordinates.longitude() && two.longitude() >= coordinates.longitude() ) ||
+             ( two.longitude() < coordinates.longitude() && one.longitude() >= coordinates.longitude() ) ) {
+            if ( one.latitude() + ( coordinates.longitude() - one.longitude()) / ( two.longitude() - one.longitude()) * ( two.latitude()-one.latitude() ) < coordinates.latitude() ) {
+                inside = !inside;
+            }
+        }
+
+        j = i;
+    }
+
+    return inside;
 }
 
+}
