@@ -1,5 +1,5 @@
 //
-// This file is part of the Marble Desktop Globe.
+// This file is part of the Marble Virtual Globe.
 //
 // This program is free software licensed under the GNU LGPL. You can
 // find a copy of this license in LICENSE.txt in the top directory of
@@ -8,21 +8,28 @@
 // Copyright 2009      Patrick Spendrin <ps_ml@gmx.de>
 //
 
-#ifndef GEODATAMULTIGEOMETRYPRIVATE_H
-#define GEODATAMULTIGEOMETRYPRIVATE_H
+#ifndef MARBLE_GEODATAMULTIGEOMETRYPRIVATE_H
+#define MARBLE_GEODATAMULTIGEOMETRYPRIVATE_H
 
 #include "GeoDataGeometry_p.h"
 
+#include "GeoDataTypes.h"
+
 namespace Marble
 {
 
-class  GeoDataMultiGeometryPrivate : public Marble::GeoDataGeometryPrivate
+class GeoDataMultiGeometryPrivate : public GeoDataGeometryPrivate
 {
   public:
      GeoDataMultiGeometryPrivate()
     {
     }
 
+     ~GeoDataMultiGeometryPrivate()
+     {
+         qDeleteAll(m_vector);
+     }
+
     virtual GeoDataGeometryPrivate* copy()
     { 
          GeoDataMultiGeometryPrivate* copy = new GeoDataMultiGeometryPrivate;
@@ -39,9 +46,9 @@ class  GeoDataMultiGeometryPrivate : public Marble::GeoDataGeometryPrivate
     {
         return GeoDataMultiGeometryId;
     }
-    QVector<GeoDataGeometry>  m_vector;
+    QVector<GeoDataGeometry*>  m_vector;
 };
 
 } // namespace Marble
 
-#endif // GeoDataMultiGeometryPRIVATE_H
+#endif
