@@ -67,13 +67,15 @@ GeoNode* DgmlStorageLayoutTagHandler::parse(GeoParser& parser) const
         GeoSceneTexture *texture = parentItem.nodeAs<GeoSceneTexture>();
 
         // Attribute mode
-        GeoSceneTexture::StorageLayout storageLayout = GeoSceneTexture::Other;
+        GeoSceneTexture::StorageLayout storageLayout = GeoSceneTexture::OpenStreetMap;
         ServerLayout *serverLayout = 0;
         const QString modeStr = parser.attribute(dgmlAttr_mode).trimmed();
         if ( modeStr == "OpenStreetMap" )
             serverLayout = new OsmServerLayout( texture );
         else if ( modeStr == "Custom" )
-            serverLayout = new CustomServerLayout();
+            serverLayout = new CustomServerLayout( texture );
+        else if ( modeStr == "WebMapService" )
+            serverLayout = new WmsServerLayout( texture );
         else {
             storageLayout = GeoSceneTexture::Marble;
             serverLayout = new MarbleServerLayout( texture );
