@@ -21,7 +21,7 @@
 
 #include "KmlPlacemarkTagHandler.h"
 
-#include <QtCore/QDebug>
+#include "MarbleDebug.h"
 
 #include "KmlElementDictionary.h"
 #include "GeoDataContainer.h"
@@ -40,18 +40,23 @@ GeoNode* KmlPlacemarkTagHandler::parse( GeoParser& parser ) const
 {
     Q_ASSERT( parser.isStartElement() && parser.isValidElement( kmlTag_Placemark ) );
 
-    GeoDataPlacemark placemark;
+    GeoDataPlacemark *placemark = new GeoDataPlacemark;
 
     GeoStackItem parentItem = parser.parentElement();
 #ifdef DEBUG_TAGS
-    qDebug() << "Parsed <" << kmlTag_Placemark << ">"
+    mDebug() << "Parsed <" << kmlTag_Placemark << ">"
              << " parent item name: " << parentItem.qualifiedName().first;
 #endif
 
     if( parentItem.represents( kmlTag_Folder ) || parentItem.represents( kmlTag_Document ) ) {
         parentItem.nodeAs<GeoDataContainer>()->append( placemark );
-        return static_cast<GeoDataPlacemark*>(&parentItem.nodeAs<GeoDataContainer>()->last());
+        return placemark;
+    } else if ( parentItem.first.first == kmlTag_kml ) {
+        GeoDataDocument* doc = geoDataDoc( parser );
+        doc->append( placemark );
+        return placemark;
     } else {
+        delete placemark;
         return 0;
     }
 }
