@@ -1,5 +1,5 @@
 //
-// This file is part of the Marble Desktop Globe.
+// This file is part of the Marble Virtual Globe.
 //
 // This program is free software licensed under the GNU LGPL. You can
 // find a copy of this license in LICENSE.txt in the top directory of
@@ -14,11 +14,14 @@
 #include "PhotoPluginModel.h"
 
 // Marble
-#include <QtCore/QDebug>
+#include "MarbleDebug.h"
 
 using namespace Marble;
+/* TRANSLATOR Marble::PhotoPlugin */
 
-PhotoPlugin::PhotoPlugin() {  
+PhotoPlugin::PhotoPlugin()
+    : m_isInitialized( false )
+{
     setNameId( "photo" );
     
     // Plugin is enabled by default
@@ -27,25 +30,36 @@ PhotoPlugin::PhotoPlugin() {
     setVisible( false );
 }
      
-void PhotoPlugin::initialize() {
-    qDebug() << "PhotoPlugin: Initialize";
-    setModel( new PhotoPluginModel( this ) );
+void PhotoPlugin::initialize()
+{
+    mDebug() << "PhotoPlugin: Initialize";
+    setModel( new PhotoPluginModel( pluginManager(), this ) );
     setNumberOfItems( numberOfImagesPerFetch );
+    m_isInitialized = true;
 }
 
-QString PhotoPlugin::name() const {
+bool PhotoPlugin::isInitialized() const
+{
+    return m_isInitialized;
+}
+
+QString PhotoPlugin::name() const
+{
     return tr( "Photos" );
 }
 
-QString PhotoPlugin::guiString() const {
+QString PhotoPlugin::guiString() const
+{
     return tr( "&Photos" );
 }
    
-QString PhotoPlugin::description() const {
+QString PhotoPlugin::description() const
+{
     return tr( "Automatically downloads images from around the world in preference to their popularity" );
 }
     
-QIcon PhotoPlugin::icon() const {
+QIcon PhotoPlugin::icon() const
+{
     return QIcon();
 }
 Q_EXPORT_PLUGIN2(PhotoPlugin, Marble::PhotoPlugin)
