@@ -1,5 +1,5 @@
 //
-// This file is part of the Marble Desktop Globe.
+// This file is part of the Marble Virtual Globe.
 //
 // This program is free software licensed under the GNU LGPL. You can
 // find a copy of this license in LICENSE.txt in the top directory of
@@ -34,8 +34,9 @@
 
 using namespace Marble;
 
-WikipediaModel::WikipediaModel( QObject *parent )
-    : AbstractDataPluginModel( "wikipedia", parent ),
+WikipediaModel::WikipediaModel( PluginManager *pluginManager,
+                                QObject *parent )
+    : AbstractDataPluginModel( "wikipedia", pluginManager, parent ),
       m_showThumbnail( true )
 {
     m_wikipediaIcon.addFile( MarbleDirs::path( "svg/wikipedia_shadow.svg" ) );
@@ -57,7 +58,7 @@ void WikipediaModel::getAdditionalItems( const GeoDataLatLonAltBox& box,
                                          qint32 number )
 {
     // Geonames only supports wikipedia articles for earth
-    if( facade->target() != "earth" ) {
+    if ( facade->target() != "earth" ) {
         return;
     }
         
@@ -87,9 +88,9 @@ void WikipediaModel::parseFile( const QByteArray& file )
     
     QList<WikipediaItem*>::iterator it;
     
-    for( it = list.begin(); it != list.end(); ++it ) {
-        if( itemExists( (*it)->id() ) ) {
-            delete (*it);
+    for ( it = list.begin(); it != list.end(); ++it ) {
+        if ( itemExists( (*it)->id() ) ) {
+            delete *it;
             continue;
         }
 
@@ -98,7 +99,7 @@ void WikipediaModel::parseFile( const QByteArray& file )
         (*it)->setTarget( "earth" );
         QUrl thumbnailImageUrl = (*it)->thumbnailImageUrl();
         if ( m_showThumbnail && !thumbnailImageUrl.isEmpty() ) {
-            downloadItemData( thumbnailImageUrl, "thumbnail", (*it) );
+            downloadItemData( thumbnailImageUrl, "thumbnail", *it );
         }
         else {
             addItemToList( *it );
