@@ -13,28 +13,39 @@
 
 #include "entryfilter.h"
 
-#include "prefs.h"
 
-#include <keduvocexpression.h>
-#include <keduvoctranslation.h>
+
+#include <KDebug>
+#include <KDialog>
+#include <KMessageBox>
+
 #include <keduvocdocument.h>
 #include <keduvocwordtype.h>
+#include <keduvocexpression.h>
 
-#include <KLocalizedString>
-#include <KMessageBox>
-#include <KDialog>
+#include "documentsettings.h"
+#include "testentry.h"
 
-EntryFilter::EntryFilter(QObject * parent, KEduVocDocument* doc) :QObject(parent)
+using namespace Practice;
+
+EntryFilter::EntryFilter(QObject * parent, KEduVocDocument* doc)
+    :QObject(parent)
+    ,m_doc(doc)
+    ,m_dialog(0)
 {
-    m_doc = doc;
-    m_dialog = 0;
     m_fromTranslation = Prefs::questionLanguage();
     m_toTranslation = Prefs::solutionLanguage();
-    expireEntries();
-}
+    kDebug() << "Filter for " << m_fromTranslation << " to " << m_toTranslation;
 
-EntryFilter::~ EntryFilter()
-{
+    m_mode = Prefs::practiceMode();
+    if (m_mode == Prefs::EnumPracticeMode::ConjugationPractice) {
+        DocumentSettings documentSettings(m_doc->url().url() + QString::number(m_toTranslation));
+        documentSettings.readConfig();
+        m_tenses = documentSettings.conjugationTenses();
+        kDebug() << "Tenses" << m_tenses;
+    }
+
+    expireEntries();
 }
 
 void EntryFilter::expireEntries()
@@ -61,7 +72,7 @@ void EntryFilter::expireEntries()
     }
 }
 
-QList<KEduVocExpression*> EntryFilter::entries()
+QList<TestEntry*> EntryFilter::entries()
 {
     // set up the lists/sets of filtered vocabulary
     m_entries = m_doc->lesson()->entries(KEduVocLesson::Recursive).toSet();
@@ -70,9 +81,22 @@ QList<KEduVocExpression*> EntryFilter::entries()
     kDebug() << "Document contains " << m_entries.count() << " valid entries.";
     if (m_entries.count() == 0) {
         KMessageBox::error(0, i18n("The vocabulary document contains no entries that can be used for the chosen type of practice."));
-        return m_entries.toList();
+        return QList<TestEntry*>();
     }
 
+    // FIXME the filtering needs to be done for each word or the grammar modes get included with written or somesuch
+
+    /* FIXME
+    if (Prefs::genderPractice())
+    {
+        if (m_doc->identifier(m_toTranslation).article().isEmpty())
+        {
+            KMessageBox::error(0, i18n("The vocabulary document contains no articles for the current language. Please add some in the Edit->Grammar menu."));
+            return QList<KEduVocExpression*>();
+        }
+    }
+    */
+
     lessonEntries();
     wordTypeEntries();
     blockedEntries();
@@ -93,7 +117,7 @@ QList<KEduVocExpression*> EntryFilter::entries()
 
         ui.lessonLabel->setText(QString::number(m_entriesLesson.count()));
         ui.wordTypeLabel->setText(QString::number(m_entriesWordType.count()));
-        ui.blockedLabel->setText(QString::number(m_entriesBlocked.count()));
+        ui.blockedLabel->setText(QString::number(m_entriesNotBlocked.count()));
         ui.timesWrongLabel->setText(QString::number(m_entriesTimesWrong.count()));
         ui.timesPracticedLabel->setText(QString::number(m_entriesTimesPracticed.count()));
         ui.minMaxGradeLabel->setText(QString::number(m_entriesMinMaxGrade.count()));
@@ -103,13 +127,11 @@ QList<KEduVocExpression*> EntryFilter::entries()
 
         ui.lessonCheckBox->setChecked(!m_entriesLesson.count());
         ui.wordTypeCheckBox->setChecked(!m_entriesWordType.count());
-        ui.blockedCheckBox->setChecked(!m_entriesBlocked.count());
+        ui.blockedCheckBox->setChecked(!m_entriesNotBlocked.count());
         ui.timesWrongCheckBox->setChecked(!m_entriesTimesWrong.count());
         ui.timesPracticedCheckBox->setChecked(!m_entriesTimesPracticed.count());
         ui.minMaxGradeCheckBox->setChecked(!m_entriesMinMaxGrade.count());
 
-        connect( m_dialog, SIGNAL(okClicked()), this, SLOT(userSelectionAccepted()) );
-        connect( m_dialog, SIGNAL(cancelClicked()), this, SLOT(userSelectionCanceled()) );
         connect( ui.lessonCheckBox, SIGNAL(toggled(bool)), this, SLOT(checkBoxChanged(bool)));
         connect( ui.wordTypeCheckBox, SIGNAL(toggled(bool)), this, SLOT(checkBoxChanged(bool)));
         connect( ui.blockedCheckBox, SIGNAL(toggled(bool)), this, SLOT(checkBoxChanged(bool)));
@@ -126,17 +148,25 @@ QList<KEduVocExpression*> EntryFilter::entries()
 
         if (m_dialog->exec() == QDialog::Rejected) {
             delete m_dialog;
-            return QList<KEduVocExpression*>();
+            return QList<TestEntry*>();
         }
         delete m_dialog;
-
     }
 
-    return m_currentSelection.toList();
+    if (m_mode == Prefs::EnumPracticeMode::ConjugationPractice) {
+        return conjugationTestEntries();
+    }
+
+    QList<TestEntry*> testEntries;
+    foreach (KEduVocExpression* entry, m_currentSelection){
+        testEntries.append(new TestEntry(entry));
+    }
+    return testEntries;
 }
 
 void EntryFilter::checkBoxChanged(bool filter)
 {
+    Q_UNUSED(filter)
     updateTotal();
 }
 
@@ -150,7 +180,7 @@ void EntryFilter::updateTotal()
         selected = selected.intersect(m_entriesWordType);
     }
     if (!m_dialog || !ui.blockedCheckBox->isChecked()) {
-        selected = selected.intersect(m_entriesBlocked);
+        selected = selected.intersect(m_entriesNotBlocked);
     }
     if (!m_dialog || !ui.timesWrongCheckBox->isChecked()) {
         selected = selected.intersect(m_entriesTimesWrong);
@@ -172,17 +202,14 @@ void EntryFilter::updateTotal()
 
 void EntryFilter::lessonEntries()
 {
+    /// @todo maybe randomize
     foreach(KEduVocExpression* entry, m_entries) {
         if (entry->lesson()->inPractice()) {
             m_entriesLesson.insert(entry);
         }
     }
-
-    //if ( Prefs::testOrderLesson() ) {
-
 }
 
-
 void EntryFilter::wordTypeEntries()
 {
     if (Prefs::wordTypesInPracticeEnabled()) {
@@ -201,21 +228,79 @@ void EntryFilter::wordTypeEntries()
 void EntryFilter::blockedEntries()
 {
     if (!Prefs::block()) {
-        m_entriesBlocked = m_entries;
+        m_entriesNotBlocked = m_entries;
         return;
     }
 
-    foreach(KEduVocExpression* entry, m_entries) {
-        int grade = entry->translation(m_toTranslation)->grade();
-        if (grade == KV_NORM_GRADE || Prefs::blockItem(grade) == 0) {
-            m_entriesBlocked.insert(entry);
-        } else {
-            QDateTime date = entry->translation(m_toTranslation)->practiceDate();
-            if (date.addSecs(Prefs::blockItem(grade)) < QDateTime::currentDateTime()) {
-                m_entriesBlocked.insert(entry);
+    switch (m_mode) {
+    case Prefs::EnumPracticeMode::ConjugationPractice:
+        foreach(KEduVocExpression* entry, m_entries) {
+            if (!isConjugationBlocked(entry->translation(m_toTranslation))) {
+                m_entriesNotBlocked.insert(entry);
+            }
+        }
+        break;
+    case Prefs::EnumPracticeMode::GenderPractice:
+        foreach(KEduVocExpression* entry, m_entries) {
+            KEduVocText article = entry->translation(m_toTranslation)->article();
+            if (!isBlocked(&article)) {
+                m_entriesNotBlocked.insert(entry);
+            }
+        }
+        break;
+    case Prefs::EnumPracticeMode::ComparisonPractice:
+        foreach(KEduVocExpression* entry, m_entries) {
+            KEduVocTranslation* translation = entry->translation(m_toTranslation);
+            KEduVocText comparative = translation->comparativeForm();
+            KEduVocText superlative = translation->superlativeForm();
+            if (!isBlocked(&(comparative))
+                || !isBlocked(&(superlative)) )
+            {
+                m_entriesNotBlocked.insert(entry);
+            }
+        }
+        break;
+    default:
+        foreach(KEduVocExpression* entry, m_entries) {
+            if (!isBlocked(entry->translation(m_toTranslation))) {
+                m_entriesNotBlocked.insert(entry);
+            }
+        }
+        break;
+    }
+}
+
+bool EntryFilter::isConjugationBlocked(KEduVocTranslation* translation) const
+{
+    foreach(const QString& tense, translation->conjugationTenses()) {
+        if(m_tenses.contains(tense)) {
+            QList<KEduVocWordFlags> pronouns = translation->conjugation(tense).keys();
+            foreach(const KEduVocWordFlags& pronoun, pronouns) {
+                KEduVocText grade = translation->conjugation(tense).conjugation(pronoun);
+                if (!isBlocked(&(grade))) {
+                    // just need to find any form that is not blocked
+                    return false;
+                }
             }
         }
     }
+    return true;
+}
+
+bool EntryFilter::isBlocked(const KEduVocText* const text) const
+{
+    grade_t grade = text->grade();
+    // always include lowest level and where blocking is off
+    if (grade == KV_NORM_GRADE || Prefs::blockItem(grade) == 0) {
+        return false;
+    } else {
+        QDateTime date = text->practiceDate();
+        if (date.addSecs(Prefs::blockItem(grade)) < QDateTime::currentDateTime()) {
+            return false;
+        }
+    }
+
+    return true;
 }
 
 void EntryFilter::timesWrongEntries()
@@ -274,13 +359,10 @@ void EntryFilter::minMaxGradeEntries()
 
 void EntryFilter::cleanupInvalid()
 {
-    bool typeTest = Prefs::testType() == Prefs::EnumTestType::ArticleTest
-            || Prefs::testType() == Prefs::EnumTestType::ComparisonTest
-            || Prefs::testType() == Prefs::EnumTestType::ConjugationTest
-            || Prefs::testType() == Prefs::EnumTestType::SynonymTest
-            || Prefs::testType() == Prefs::EnumTestType::AntonymTest
-            || Prefs::testType() == Prefs::EnumTestType::ParaphraseTest
-            || Prefs::testType() == Prefs::EnumTestType::ExampleTest;
+    Prefs::EnumPracticeMode::type mode = Prefs::practiceMode();
+    bool wordTypeNeeded = (mode == Prefs::EnumPracticeMode::GenderPractice) ||
+        (mode == Prefs::EnumPracticeMode::ComparisonPractice) ||
+        (mode == Prefs::EnumPracticeMode::ConjugationPractice);
 
     QSet<KEduVocExpression*>::iterator i = m_entries.begin();
     while (i != m_entries.end()) {
@@ -288,65 +370,101 @@ void EntryFilter::cleanupInvalid()
         if ((*i)->translation(m_toTranslation)->text().isEmpty()
               || (*i)->translation(m_fromTranslation)->text().isEmpty()) {
             i = m_entries.erase(i);
-        } else if (typeTest) {
-            if(!(*i)->translation(m_toTranslation)->wordType()) {
-                i = m_entries.erase(i);
-            } else {
-                switch (Prefs::testType()) {
-    // if we do a grammar test, check if the grammar type is valid
-                case Prefs::EnumTestType::ArticleTest:
-                    if (! ((*i)->translation(m_toTranslation)->wordType()->wordType() & KEduVocWordFlag::Noun)) {
-                        i = m_entries.erase(i);
-                    } else i++;
-                    break;
-                case Prefs::EnumTestType::ComparisonTest:
-                    if (! ((Prefs::comparisonIncludeAdjective() &&(*i)->translation(m_toTranslation)->wordType()->wordType()
-                                == KEduVocWordFlag::Adjective)
-                           || (Prefs::comparisonIncludeAdverb() &&(*i)->translation(m_toTranslation)->wordType()->wordType()
-                           == KEduVocWordFlag::Adverb))) {
-                        i = m_entries.erase(i);
-                    } else {
-                        if ((*i)->translation(m_toTranslation)->comparative().isEmpty() &&
-                                    (*i)->translation(m_toTranslation)->superlative().isEmpty()) {
-                            i = m_entries.erase(i);
-                        } else i++;
-                    }
-                    break;
-                case Prefs::EnumTestType::ConjugationTest:
-                    if ( (*i)->translation(m_toTranslation)->wordType()->wordType() != KEduVocWordFlag::Verb || (*i)->translation(m_toTranslation)->conjugations().count() == 0) {
-                        i = m_entries.erase(i);
-                    } else i++; // conjugation
-                    break;
-
-                case Prefs::EnumTestType::SynonymTest:
-                    if ((*i)->translation(m_toTranslation)->synonym().simplified().isEmpty()){
-                        i = m_entries.erase(i);
-                    } else i++;
-                    break;
-                case Prefs::EnumTestType::AntonymTest:
-                    if ((*i)->translation(m_toTranslation)->antonym().simplified().isEmpty()){
-                        i = m_entries.erase(i);
-                    } else i++;
-                    break;
-                case Prefs::EnumTestType::ParaphraseTest:
-                    if ((*i)->translation(m_toTranslation)->paraphrase().simplified().isEmpty()){
-                        i = m_entries.erase(i);
-                    } else i++;
-                    break;
-                case Prefs::EnumTestType::ExampleTest:
-                    if ((*i)->translation(m_toTranslation)->example().simplified().isEmpty()){
-                        i = m_entries.erase(i);
-                    } else i++;
-                    break;
-                } // switch
-            } // type valid
-        } else { // if typeTest
-            i++;
+            continue;
         }
-    } // for
+               
+        // for grammar stuff we need the word to have its word type set, else continue
+        if (wordTypeNeeded && !(*i)->translation(m_toTranslation)->wordType()) {
+            i = m_entries.erase(i);
+            continue;
+        }
+        
+        // Grammar modes need different things:
+        switch (Prefs::practiceMode()) {     
+        
+        // example sentences: need the example sentence to exist
+        case Prefs::EnumPracticeMode::ExampleSentencesPractice:
+            if ((*i)->translation(m_toTranslation)->example().simplified().isEmpty()){
+                i = m_entries.erase(i);
+                continue;
+            }
+            break;
+            
+        case Prefs::EnumPracticeMode::GenderPractice:
+            if (!((*i)->translation(m_toTranslation)->wordType()->wordType() & KEduVocWordFlag::Noun)) {
+                i = m_entries.erase(i);
+                continue;
+            }
+            break;
 
+        case Prefs::EnumPracticeMode::ComparisonPractice:
+            if (
+                // only adjective/adverb
+                (((*i)->translation(m_toTranslation)->wordType()->wordType() != KEduVocWordFlag::Adjective)
+                    && ((*i)->translation(m_toTranslation)->wordType()->wordType() != KEduVocWordFlag::Adverb))
+                // at least one comparison forms is there
+                || ((*i)->translation(m_toTranslation)->comparative().isEmpty() || (*i)->translation(m_toTranslation)->superlative().isEmpty())) {
+                i = m_entries.erase(i);
+                continue;
+            }
+            break;
+
+        case Prefs::EnumPracticeMode::ConjugationPractice:
+            if ( (*i)->translation(m_toTranslation)->wordType()->wordType() != KEduVocWordFlag::Verb 
+                || (*i)->translation(m_toTranslation)->conjugations().count() == 0) {
+                // FIXME should also check tenses
+                i = m_entries.erase(i);
+                continue;
+            } // conjugation
+            break;
+        default:
+            break;
+        } // switch
+        i++;
+    } // for
     kDebug() << "Invalid items removed. Remaining: " << m_entries.count();
 }
 
+QList< TestEntry* > EntryFilter::conjugationTestEntries() const
+{
+    kDebug() << "Filtering conjugation entries for tenses... " << m_tenses;
+
+    QList<TestEntry*> testEntries;
+    foreach (KEduVocExpression* entry, m_currentSelection){
+        foreach(const QString& tense, entry->translation(m_toTranslation)->conjugationTenses()) {
+            if(m_tenses.contains(tense)) {
+                QList<KEduVocWordFlags> pronouns = entry->translation(m_toTranslation)->conjugation(tense).keys();
+                foreach(const KEduVocWordFlags& pronoun, pronouns) {
+                    if (!isBlocked(&(entry->translation(m_toTranslation)->conjugation(tense).conjugation(pronoun)))) {
+                        TestEntry* testEntry = new TestEntry(entry);
+                        testEntry->setConjugationTense(tense);
+                        testEntries.append(testEntry);
+                    }
+                }
+            }
+        }
+    }
+    return testEntries;
+    /*
+    // FIXME tense selection
+    QStringList possibleTenses;
+    foreach(const QString& practiceTense, m_tenses) {
+        if (m_current->entry()->translation(m_practiceOptions.languageTo())
+            ->conjugationTenses().contains(practiceTense)) {
+            possibleTenses.append(practiceTense);
+        }
+    }
+    if (possibleTenses.isEmpty()) {
+        kDebug() << "No valid practice tenses in entry: " << m_current->entry()->translation(m_practiceOptions.languageTo())->text()
+            << m_current->entry()->translation(m_practiceOptions.languageTo())->conjugationTenses()
+            << m_tenses;
+        return false;
+    }
+
+    m_currentTense = possibleTenses.first();
+    */
+
+}
+
 
 #include "entryfilter.moc"
